import { createRouter, createWebHashHistory } from 'vue-router'
import LayoutIndex from '@/components/Layout/LayoutIndex.vue'
import { useSystemStore } from '@/stores/system.js'

const router = createRouter({
  history: createWebHashHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/login',
      component: () => import('@/views/LoginView.vue'),
    },
    {
      path: '/',
      component: LayoutIndex,
      redirect: '/home',
      children: [
        {
          path: '/home',
          meta: { needLogin: true },
          component: () => import('@/views/HomeView.vue'),
        },
        {
          path: '/system',
          children: [
            {
              path: '/system/account',
              meta: { needLogin: true, needMenu: true },
              component: () => import('@/views/AccountView.vue'),
            },
            {
              path: '/system/role',
              meta: { needLogin: true, needMenu: true },
              component: () => import('@/views/RoleView.vue'),
            },
            {
              path: '/system/authority',
              meta: { needLogin: true, needMenu: true },
              component: () => import('@/views/AuthorityView.vue'),
            },
            {
              path: '/system/tenant',
              meta: { needLogin: true, needMenu: true },
              component: () => import('@/views/TenantView.vue'),
            },
            {
              path: '/system/logger',
              meta: { needLogin: true, needMenu: true },
              component: () => import('@/views/LoggerView.vue'),
            },
          ],
        },
        {
          path: '/message',
          name: 'Message',
          component: () => import('@/views/MessageView.vue'),
        },
        {
          path: '/webview',
          name: 'WebView',
          props: (route) => ({ link: route.query.link || '#' }),
          component: () => import('@/views/WebView.vue'),
        },
        {
          path: '403',
          component: () => import('@/views/exception/403View.vue'),
        },
        {
          path: '500',
          component: () => import('@/views/exception/500View.vue'),
        },
        {
          path: '/:pathMatch(.*)*',
          component: () => import('@/views/exception/404View.vue'),
        },
      ],
    },
  ],
})

router.beforeEach((to, from, next) => {
  const systemStore = useSystemStore()
  // 判断是否需要登录
  if (to.meta.needLogin && !systemStore.isLogin) {
    return next('/login')
  }
  // 判断是否拥有菜单权限
  if (to.meta.needMenu && !systemStore.menus.some((item) => to.path.startsWith(item.path))) {
    return next('/403')
  }
  return next()
})

export default router
