import { defineStore } from 'pinia'
import { jwtDecode } from 'jwt-decode'
import Cookies from 'js-cookie'
import axios from '@/http/api.js'
import { fromArray, map } from 'tree-lodash'
import { toRaw } from 'vue'

const TokenKey = 'Sa-Token'

export const useSystemStore = defineStore('system', {
  state: () => {
    return {
      token: '', // 令牌
      name: '', // 用户名
      realName: '', // 显示姓名
      tenant: '', // 租户
      auths: [], // 角色和权限
      menus: [], // 菜单
    }
  },
  getters: {
    isSa(state) {
      return !state.tenant
    },
    isLogin(state) {
      return !!state.token
    },
    fmtMenus(state) {
      return map(fromArray(toRaw(state.menus), { parentKey: 'parentId' }), (item) => ({
        key: item.path || item.value,
        label: item.name,
        link: item.link || '',
      }))
    },
  },
  actions: {
    // 解析令牌
    parseToken() {
      let token = Cookies.get(TokenKey)
      if (token) {
        this.token = token
        var payload = jwtDecode(token)
        this.name = payload['name']
        this.realName = payload['real_name']
        this.tenant = payload['tenant']
      } else {
        useSystemStore().$reset()
      }
    },
    // 获得角色和权限
    ownAuths() {
      let token = Cookies.get(TokenKey)
      if (token) {
        axios.get('/manager/own/auths').then(([_, res]) => (this.auths = res.data || []))
      }
    },
    // 获得菜单
    ownMenus() {
      let token = Cookies.get(TokenKey)
      if (token) {
        axios.get('/manager/own/menus').then(([_, res]) => (this.menus = res.data || []))
      }
    },
    // 初始化
    init() {
      this.parseToken()
      this.ownAuths()
      this.ownMenus()
    },
  },
  persist: true,
})
