# {{ cookiecutter.project_hans }}

## 后端快速开始

1. 创建数据库

  ```sql
  # mysql
  CREATE DATABASE `{{ cookiecutter.mvn_artifact_id }}` DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci;
  ```

  ```sql
  # postgis 启用 gis 扩展
  CREATE DATABASE {{ cookiecutter.mvn_artifact_id }} WITH ENCODING = 'utf8';
  CREATE EXTENSION postgis;
  ```

2. 项目运行

  ```shell
  mvn spring-boot:run
  ```
3. 项目发布，修改 yml 配置文件选择发布配置

  ```shell
  mvn package
  ```

4. 项目运行

  ```shell
  java -jar {{ cookiecutter.mvn_artifact_id }}-0.0.1-SNAPSHOT.jar
  ```

## 管理后台快速开始

1. 安装项目依赖

  ```shell
  npm i
  ```

2. 运行

  ```shell
  npm run dev
  ```

3. 发布后，会打包至后端的资源文件夹 manager-ui 下

  ```shell
  npm run build:prod
  ```

## 访问地址

1. 接口文档路径 [swagger-ui](http://localhost:8080/swagger-ui.html)
2. 后台管理路径 [manager-ui](http://localhost:8080/manager-ui.html)

## 注意事项

1. 修改项目常量 `{{ cookiecutter.__mvn_package }}.common.Constants`
2. 前后端 RSA 密钥替换 `{{ cookiecutter.__mvn_package }}.utils.CryptoUtil`

## 代码生成

1. Idea 安装插件 [EasyCode-MybatisCodeHelper](https://plugins.jetbrains.com/plugin/13847-easycode-mybatiscodehelper)
2. Idea 安装插件 [CheckStyle-IDEA](https://plugins.jetbrains.com/plugin/1065-checkstyle-idea)
3. Idea 开发工具连接数据库 {{ cookiecutter.mvn_artifact_id }}
4. 数据库表名右键即可生成代码

## 文件夹说明

```
 ── {{cookiecutter.project_slug}}                             {{ cookiecutter.project_hans }} 项目
    ├── CheckStyle                                            代码样式检查的配置
    ├── ManagerUI                                             Vue.js 的后台项目
    ├── files                                                 接口上传文件
    ├── EasyCode                                              代码生成工具模版
    └── src
        ├── main
        │   ├── java
        │   │   └── {{cookiecutter.__package_path}}
        │   │      ├── common                                 常量
        │   │      ├── config                                 配置
        │   │      ├── enums                                  枚举
        │   │      ├── mapper                                 对象转换
        │   │      ├── module                                 业务模块
        │   │      │   ├── dao                                自定义 SQL 语句
        │   │      │   ├── manager                            后台管理接口
        │   │      │   │   └── request                        自定义请求体
        │   │      │   └── schedule                           定时任务
        │   │      ├── rest                                   代码生成 Restful 接口
        │   │      │   ├── api
        │   │      │   ├── controller
        │   │      │   ├── dao
        │   │      │   ├── entity
        │   │      │   ├── enums
        │   │      │   ├── exceptions
        │   │      │   └── service
        │   │      │       └── impl
        │   │      ├── service                                自定义服务
        │   │      │   └── impl
        │   │      ├── utils                                  常用工具
        │   │      └── web                                    Web 配置
        │   └── resources
        |       ├── application.yml                           配置文件
        |       ├── schema.sql                                数据库结构，项目启动时运行
        │       ├── mapper                                    代码生成
        │       └── static                                    静态资源
        |           └── manager-ui                            后端管理网页
        └── test                                              单元测试
```