package {{ cookiecutter.__mvn_package }}.config;

import com.github.benmanes.caffeine.cache.Caffeine;
import java.util.List;
import java.util.concurrent.TimeUnit;
import lombok.AllArgsConstructor;
import org.springframework.cache.CacheManager;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.cache.caffeine.CaffeineCache;
import org.springframework.cache.support.SimpleCacheManager;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * (CaffeineConfig) 本地缓存.
 *
 * @author zweiandlen
 * @since 2024/6/13 下午3:02
 */
@Configuration
@EnableCaching
public class CacheConfig {

  // 验证码有效时常，默认10分钟
  public static final int CAPTCHA_OVER_TIME = 600;
  // 数据库缓存时间，默认1小时
  public static final int DATA_OVER_TIME = 3600;

  /**
   * 缓存管理器，包含不同的缓存配置.
   *
   * @return 缓存管理
   */
  @Bean
  public CacheManager cacheManager() {
    SimpleCacheManager cacheManager = new SimpleCacheManager();
    List<CaffeineCache> caches =
        List.of(
            new CaffeineCache(
                CacheEnum.CAPTCHA.name(),
                Caffeine.newBuilder()
                    .expireAfterWrite(CacheEnum.CAPTCHA.ttl, TimeUnit.SECONDS)
                    .maximumSize(CacheEnum.CAPTCHA.max)
                    .build()),
            new CaffeineCache(
                CacheEnum.DATA.name(),
                Caffeine.newBuilder()
                    .expireAfterWrite(CacheEnum.DATA.ttl, TimeUnit.SECONDS)
                    .maximumSize(CacheEnum.DATA.max)
                    .build()));

    cacheManager.setCaches(caches);
    return cacheManager;
  }

  /** 缓存配置枚举. */
  @AllArgsConstructor
  public enum CacheEnum {
    CAPTCHA(CAPTCHA_OVER_TIME, 100),
    DATA(DATA_OVER_TIME, 1000);

    private final long ttl;
    private final int max;
  }
}
