package {{ cookiecutter.__mvn_package }}.config;

import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.BlockAttackInnerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.OptimisticLockerInnerInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import {{ cookiecutter.__mvn_package }}.common.Constants;
import {{ cookiecutter.__mvn_package }}.utils.ThreadLocalUtil;
import {{ cookiecutter.__mvn_package }}.web.DataChangeInnerInterceptor;
import {{ cookiecutter.__mvn_package }}.web.OrgLineInnerInterceptor;
import java.time.OffsetDateTime;
import java.util.Properties;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

/**
 * (MybatisConfig) Mybatis配置.
 *
 * @author zweiandlen
 * @since 2024/3/28 10:13
 */
@Slf4j
@Component
public class MybatisConfig implements MetaObjectHandler {

  private OrgLineInnerInterceptor orgLineInnerInterceptor;

  public MybatisConfig(OrgLineInnerInterceptor orgLineInnerInterceptor) {
    this.orgLineInnerInterceptor = orgLineInnerInterceptor;
  }

  @Override
  public void insertFill(MetaObject metaObject) {
    this.fillStrategy(metaObject, "createTime", OffsetDateTime.now());
    this.fillStrategy(
        metaObject,
        "createBy",
        ThreadLocalUtil.getByKey(
            Constants.REAL_NAME, ThreadLocalUtil.getByKey(Constants.NAME, "匿名")));
  }

  @Override
  public void updateFill(MetaObject metaObject) {
    metaObject.setValue("updateTime", OffsetDateTime.now());
    metaObject.setValue(
        "updateBy",
        ThreadLocalUtil.getByKey(
            Constants.REAL_NAME, ThreadLocalUtil.getByKey(Constants.NAME, "匿名")));
  }

  /**
   * Mybatis 插件配置.
   *
   * @return 拦截器
   */
  @Bean
  public MybatisPlusInterceptor mybatisPlusInterceptor() {
    MybatisPlusInterceptor interceptor = new MybatisPlusInterceptor();
    // 多租户插件
    interceptor.addInnerInterceptor(orgLineInnerInterceptor);
    // 分页插件
    {% if cookiecutter.platform == "mysql" -%}
    interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.MYSQL));
    {% elif cookiecutter.platform == "postgis" -%}
    interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.POSTGRE_SQL));
    {% endif %}
    // 乐观锁插件
    interceptor.addInnerInterceptor(new OptimisticLockerInnerInterceptor(true));
    // 防止全表更新、删除插件
    interceptor.addInnerInterceptor(new BlockAttackInnerInterceptor());
    // 数据变动记录插件，自定义
    DataChangeInnerInterceptor dataChangeInnerInterceptor = new DataChangeInnerInterceptor();
    Properties dataChangeProperties = new Properties();
    dataChangeProperties.setProperty(
        "ignoredTableColumns", "logger.*;*.version,create_time,update_time");
    dataChangeInnerInterceptor.setProperties(dataChangeProperties);
    interceptor.addInnerInterceptor(dataChangeInnerInterceptor);
    return interceptor;
  }
}
