package {{ cookiecutter.__mvn_package }}.config;

import cn.dev33.satoken.interceptor.SaInterceptor;
import cn.dev33.satoken.router.SaRouter;
import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.plugins.IgnoreStrategy;
import com.baomidou.mybatisplus.core.plugins.InterceptorIgnoreHelper;
import {{ cookiecutter.__mvn_package }}.common.Constants;
import {{ cookiecutter.__mvn_package }}.utils.ThreadLocalUtil;
import {{ cookiecutter.__mvn_package }}.web.SuperManager;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import java.io.File;
import org.dromara.hutool.core.io.file.FileUtil;
import org.dromara.hutool.core.map.MapBuilder;
import org.dromara.hutool.core.map.MapUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.extra.management.ManagementUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.AsyncHandlerInterceptor;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

/**
 * (WebConfig) Mvc 配置.
 *
 * @author zweiandlen
 * @since 2024/3/26 09:12
 */
@Configuration
public class WebConfig implements WebMvcConfigurer {

  @Resource SuperManager superManager;

  @Value("${file.path:}")
  private String path;

  @Override
  public void addResourceHandlers(ResourceHandlerRegistry registry) {
    // 创建文件夹
    if (StrUtil.isBlank(this.path)) {
      // 默认在jar包所在位置创建 files 文件夹
      String currentDir = ManagementUtil.getUserInfo().getCurrentDir();
      File files = FileUtil.file(currentDir, "files");
      this.path = StrUtil.replace(files.getAbsolutePath(), StrUtil.BACKSLASH, StrUtil.SLASH);
      this.path = StrUtil.appendIfMissing(this.path, StrUtil.SLASH);
      FileUtil.mkdir(files);
    } else {
      // 在配置文件位置创建 files 文件夹
      this.path = StrUtil.replace(this.path, StrUtil.BACKSLASH, StrUtil.SLASH);
      this.path = StrUtil.appendIfMissing(this.path, StrUtil.SLASH);
      FileUtil.mkdir(this.path);
    }
    // 作为资源路径
    registry.addResourceHandler("/files/**").addResourceLocations("file:" + this.path);
    WebMvcConfigurer.super.addResourceHandlers(registry);
  }

  @Override
  public void addInterceptors(InterceptorRegistry registry) {

    registry.addInterceptor(
        new AsyncHandlerInterceptor() {

          // 请求开始时的拦截策略
          @Override
          public boolean preHandle(
              HttpServletRequest request, HttpServletResponse response, Object handler)
              throws Exception {
            // 请求时设置共享值
            if (StpUtil.isLogin()) {
              MapBuilder<String, Object> builder =
                  MapUtil.<String, Object>builder()
                      .put(
                          Constants.NAME,
                          StrUtil.defaultIfBlank(
                              String.valueOf(StpUtil.getExtra(Constants.NAME)), StrUtil.EMPTY))
                      .put(
                          Constants.REAL_NAME,
                          StrUtil.defaultIfBlank(
                              String.valueOf(StpUtil.getExtra(Constants.REAL_NAME)), StrUtil.EMPTY))
                      .put(
                          Constants.TENANT,
                          StrUtil.defaultIfBlank(
                              String.valueOf(StpUtil.getExtra(Constants.TENANT)), StrUtil.EMPTY));
              ThreadLocalUtil.setMap(builder.build());
            }
            // 超级管理员时忽略租户
            if (superManager.isReal()) {
              InterceptorIgnoreHelper.handle(IgnoreStrategy.builder().tenantLine(true).build());
            }
            return AsyncHandlerInterceptor.super.preHandle(request, response, handler);
          }

          // 请求结束时启用所有的拦截策略，清空上下文
          @Override
          public void afterCompletion(
              HttpServletRequest request,
              HttpServletResponse response,
              Object handler,
              Exception ex)
              throws Exception {
            // 清除上下文
            ThreadLocalUtil.clear();
            // 启用mybatisplus的拦截策略
            InterceptorIgnoreHelper.clearIgnoreStrategy();
            AsyncHandlerInterceptor.super.afterCompletion(request, response, handler, ex);
          }
        });

    // 路由拦截
    registry
        .addInterceptor(
            new SaInterceptor(
                handle -> {
                  // 校验登录
                  SaRouter.match("/**")
                      .notMatch(
                          "/error/**",
                          "/files/**",
                          "/index.html",
                          "/pub/**",
                          "/v3/api-docs/**",
                          "/swagger-ui/**",
                          "/swagger-ui.html",
                          "/manager-ui/**",
                          "/manager-ui.html",
                          "/manager/login",
                          "/manager/register")
                      .check(r -> StpUtil.checkLogin());
                  // 校验权限
                  SaRouter.match("/db/**", r -> StpUtil.checkPermission("db:rest"));
                }))
        .addPathPatterns("/**");
    WebMvcConfigurer.super.addInterceptors(registry);
  }

  //  @Override
  //  public void addCorsMappings(CorsRegistry registry) {
  //    WebMvcConfigurer.super.addCorsMappings(registry);
  //    registry
  //        .addMapping("/**")
  //        .allowedOriginPatterns("*")
  //        .allowCredentials(true)
  //        .allowedHeaders("*")
  //        .allowedMethods("GET", "POST", "PUT", "DELETE", "OPTIONS")
  //        .maxAge(3600);
  //  }
}
