package {{ cookiecutter.__mvn_package }}.enums;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Arrays;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * (EAuthorityType) 权限类型.
 *
 * @author zweiandlen
 * @since 2024/4/10 上午11:40
 */
@Schema(
    enumAsRef = true,
    description =
        """
    权限表，分类(type)

    0 - 后台接口
    1 - 前台菜单
    2 - 前台按钮
    """)
@Getter
@AllArgsConstructor
public enum AuthorityType {
  INTERFACE(0, "接口"),
  MENU(1, "菜单"),
  BUTTON(2, "按钮");

  @EnumValue private final int field;
  private final String description;

  /**
   * 创建枚举.
   *
   * @param field 值
   * @return 枚举
   */
  @JsonCreator
  public static AuthorityType valueOf(int field) {
    return Arrays.stream(AuthorityType.values())
        .filter(i -> i.field == field)
        .findFirst()
        .orElse(null);
  }

  @JsonValue
  public int getField() {
    return field;
  }
}
