package {{ cookiecutter.__mvn_package }}.mapper;

import {{ cookiecutter.__mvn_package }}.mapper.entity.AccountExcel;
import {{ cookiecutter.__mvn_package }}.module.manager.request.AccountPassword;
import {{ cookiecutter.__mvn_package }}.module.manager.request.AccountRegister;
import {{ cookiecutter.__mvn_package }}.rest.entity.Account;
import java.util.List;
import org.dromara.hutool.core.text.StrUtil;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;

/**
 * 凭据表(AccountMapper)表数据库访问层.
 *
 * @author zweiandlen
 * @since 2024/7/5 上午9:48
 */
@Mapper(uses = {ConvertWorker.class})
public interface AccountMapper {
  Account toAccount(AccountRegister account);

  Account toAccount(AccountPassword account);

  @Mapping(target = "isActive", source = "isActive", qualifiedByName = "toActiveStr")
  @Mapping(target = "status", source = "status", qualifiedByName = "toStatusStr")
  AccountExcel toExcel(Account account);

  List<AccountExcel> toExcel(List<Account> accounts);

  @Mapping(
      target = "password",
      source = "password",
      defaultValue = "$2a$10$t/cCJoxEWFbVRJy3MAfQhe4/7EeB2sCxE0BcIL6Pz/A28D/Xw0A9K")
  @Mapping(target = "isActive", source = "isActive", qualifiedByName = "toActiveId")
  @Mapping(target = "status", source = "status", qualifiedByName = "toStatusId")
  @Mapping(target = "version", ignore = true)
  @Mapping(target = "deleteTime", ignore = true)
  @Mapping(target = "createTime", ignore = true)
  @Mapping(target = "updateTime", ignore = true)
  @Mapping(target = "createBy", ignore = true)
  @Mapping(target = "updateBy", ignore = true)
  @Mapping(target = "tenant", source = "tenant", defaultValue = "")
  Account toEntity(AccountExcel excel);

  List<Account> toEntity(List<AccountExcel> excels);

  /** 空字符串转化为null. */
  default Long pkEmptyStr(String pk) {
    return StrUtil.isEmptyIfStr(pk) ? null : Long.parseLong(pk);
  }

  @Named("toActiveId")
  default Integer toActiveId(String active) {
    return switch (active) {
      case "激活" -> 0;
      case "未激活" -> 1;
      default -> 0;
    };
  }

  @Named("toActiveStr")
  default String toActiveStr(Integer active) {
    return switch (active) {
      case 0 -> "激活";
      case 1 -> "未激活";
      default -> "其他";
    };
  }

  @Named("toStatusId")
  default Integer toStatusId(String status) {
    return switch (status) {
      case "可用" -> 0;
      case "禁用" -> 1;
      default -> 0;
    };
  }

  @Named("toStatusStr")
  default String toStatusStr(Integer status) {
    return switch (status) {
      case 0 -> "可用";
      case 1 -> "禁用";
      default -> "其他";
    };
  }
}
