package {{ cookiecutter.__mvn_package }}.module.manager;

import cn.dev33.satoken.secure.BCrypt;
import cn.dev33.satoken.stp.SaLoginModel;
import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.plugins.IgnoreStrategy;
import com.baomidou.mybatisplus.core.plugins.InterceptorIgnoreHelper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import {{ cookiecutter.__mvn_package }}.common.Constants;
import {{ cookiecutter.__mvn_package }}.enums.Status;
import {{ cookiecutter.__mvn_package }}.mapper.AccountMapper;
import {{ cookiecutter.__mvn_package }}.module.manager.request.AccountLogin;
import {{ cookiecutter.__mvn_package }}.module.manager.request.AccountPassword;
import {{ cookiecutter.__mvn_package }}.module.manager.request.AccountRegister;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Account;
import {{ cookiecutter.__mvn_package }}.rest.entity.Tenant;
import {{ cookiecutter.__mvn_package }}.rest.service.AccountService;
import {{ cookiecutter.__mvn_package }}.rest.service.TenantService;
import {{ cookiecutter.__mvn_package }}.service.CaptchaService;
import {{ cookiecutter.__mvn_package }}.utils.CryptoUtil;
import {{ cookiecutter.__mvn_package }}.web.SuperManager;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

/**
 * (LoginController).
 *
 * @author zweiandlen
 * @since 2024/7/3 下午3:24
 */
@Tag(name = "管理接口", description = "需要令牌")
@RestController
@RequestMapping("manager")
public class LoginController {

  @Resource SuperManager superManager;
  @Resource AccountMapper accountMapper;
  @Resource CaptchaService captchaService;
  @Resource AccountService accountService;
  @Resource TenantService tenantService;

  /**
   * 凭据登录.
   *
   * @param account 请求体
   * @return 响应结果
   */
  @Operation(summary = "凭据登录", description = "公钥：" + CryptoUtil.PUB)
  @PostMapping("login")
  public R doLogin(@Valid @RequestBody AccountLogin account) {
    // 忽略租户
    InterceptorIgnoreHelper.handle(IgnoreStrategy.builder().tenantLine(true).build());
    if (StrUtil.isNotBlank(account.getCaptcha()) && StrUtil.isNotBlank(account.getCaptchaId())) {
      if (!captchaService.checkCodeById(account.getCaptchaId(), account.getCaptcha())) {
        throw new RuntimeException("验证码错误");
      }
    } else {
      throw new RuntimeException("验证码与回执不能为空");
    }
    // 判断是否超级管理员
    if (StrUtil.isNotBlank(account.getName())) {
      String decrypt = CryptoUtil.decrypt(account.getName());
      if (StrUtil.equalsIgnoreCase(superManager.getUsername(), decrypt)) {
        // 校验密码
        if (!StrUtil.equals(
            CryptoUtil.decrypt(account.getPassword()), superManager.getPassword())) {
          throw new RuntimeException("密码错误");
        }
        // 写入登录参数
        SaLoginModel model = new SaLoginModel();
        model.setExtra(Constants.NAME, superManager.getUsername());
        model.setExtra(Constants.REAL_NAME, superManager.getRealName());
        model.setExtra(Constants.TENANT, superManager.getTenant());
        StpUtil.login(superManager.getUsername(), model);
        return R.ok("超级管理员登录成功");
      }
    }
    // 查找已有凭据
    Account find = null;
    if (StrUtil.isNotBlank(account.getName())) {
      String decrypt = CryptoUtil.decrypt(account.getName());
      find =
          accountService.getOne(Wrappers.lambdaQuery(Account.class).eq(Account::getName, decrypt));
    } else if (StrUtil.isNotBlank(account.getMobile())) {
      String decrypt = CryptoUtil.decrypt(account.getMobile());
      find =
          accountService.getOne(
              Wrappers.lambdaQuery(Account.class).eq(Account::getMobile, decrypt));
      account.setName(account.getMobile());
    } else if (StrUtil.isNotBlank(account.getEmail())) {
      String decrypt = CryptoUtil.decrypt(account.getEmail());
      find =
          accountService.getOne(Wrappers.lambdaQuery(Account.class).eq(Account::getEmail, decrypt));
      account.setName(StrUtil.subBefore(account.getName(), "@", false));
    } else {
      throw new RuntimeException("凭据不存在");
    }
    if (find == null) {
      throw new RuntimeException("凭据不存在");
    }
    // 校验凭据状态
    if (find.getStatus() != Status.ENABLE.getField()) {
      throw new RuntimeException("凭据已禁用");
    }
    // 校验密码
    if (!BCrypt.checkpw(CryptoUtil.decrypt(account.getPassword()), find.getPassword())) {
      throw new RuntimeException("密码错误");
    }
    // 写入登录参数
    SaLoginModel model = new SaLoginModel();
    model.setExtra(Constants.NAME, find.getName());
    model.setExtra(Constants.REAL_NAME, find.getRealName());
    model.setExtra(Constants.TENANT, find.getTenant());
    StpUtil.login(String.valueOf(find.getId()), model);
    return R.ok("登录成功");
  }

  /**
   * 凭据注册.
   *
   * @param account 请求体
   * @return 响应结果
   */
  @Transactional
  @Operation(summary = "凭据注册")
  @PostMapping("register")
  public R register(@Valid @RequestBody AccountRegister account) {
    // 忽略租户
    InterceptorIgnoreHelper.handle(IgnoreStrategy.builder().tenantLine(true).build());
    if (StrUtil.isNotBlank(account.getCaptcha()) && StrUtil.isNotBlank(account.getCaptchaId())) {
      if (!captchaService.checkCodeById(account.getCaptchaId(), account.getCaptcha())) {
        throw new RuntimeException("验证码错误");
      }
    } else {
      throw new RuntimeException("验证码与回执不能为空");
    }
    // 查找已有凭据
    Account find = null;
    if (StrUtil.isNotBlank(account.getName())) {
      find =
          accountService.getOne(
              Wrappers.lambdaQuery(Account.class).eq(Account::getName, account.getName()));
    } else if (StrUtil.isNotBlank(account.getMobile())) {
      find =
          accountService.getOne(
              Wrappers.lambdaQuery(Account.class).eq(Account::getMobile, account.getMobile()));
      account.setName(account.getMobile());
    } else if (StrUtil.isNotBlank(account.getEmail())) {
      find =
          accountService.getOne(
              Wrappers.lambdaQuery(Account.class).eq(Account::getEmail, account.getEmail()));
      account.setName(StrUtil.subBefore(account.getEmail(), "@", false));
    }
    if (find != null) {
      throw new RuntimeException("该凭据已存在");
    }
    // 新建租户
    Tenant findTenant =
        tenantService.getOne(
            Wrappers.lambdaQuery(Tenant.class).eq(Tenant::getName, account.getTenant()));
    if (findTenant == null) {
      Tenant tenant = new Tenant();
      tenant.setName(account.getTenant());
      tenant.setDescription("创建凭据时自动生成");
      tenantService.save(tenant);
    }
    // 新建凭据
    Account mapperAccount = accountMapper.toAccount(account);
    mapperAccount.setPassword(BCrypt.hashpw(account.getPassword()));
    return R.ok(accountService.save(mapperAccount));
  }

  /**
   * 密码修改.
   *
   * @param account 请求体
   * @return 响应结果
   */
  @Operation(summary = "密码修改")
  @PutMapping("password")
  public R password(@Valid @RequestBody AccountPassword account) {
    // 查找已有凭据
    Account find = accountService.getById(account.getId());
    if (find == null) {
      throw new RuntimeException("凭据不存在");
    }
    // 修改密码
    Account mapperAccount = accountMapper.toAccount(account);
    mapperAccount.setPassword(BCrypt.hashpw(account.getPassword()));
    return R.ok(accountService.updateById(mapperAccount));
  }

  @Operation(summary = "凭据注销")
  @PostMapping("logout")
  public R logout() {
    StpUtil.logout();
    return R.ok("注销成功");
  }
}
