package {{ cookiecutter.__mvn_package }}.module.manager;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.common.Constants;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Message;
import {{ cookiecutter.__mvn_package }}.rest.service.MessageService;
import {{ cookiecutter.__mvn_package }}.utils.ThreadLocalUtil;
import {{ cookiecutter.__mvn_package }}.web.SuperManager;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.io.Serializable;
import java.time.OffsetDateTime;
import java.time.ZoneOffset;
import java.util.List;
import org.dromara.hutool.core.date.DateField;
import org.dromara.hutool.core.date.DateTime;
import org.dromara.hutool.core.date.DateUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;

/**
 * (MessageController)
 *
 * @author zweiandlen
 * @since 2025/4/21 09:32
 */
@Tag(name = "消息接口", description = "需要令牌")
@RestController
@RequestMapping("message")
public class MessageController extends ApiController {

  /** 服务对象. */
  private final SuperManager superManager;

  private final MessageService messageService;

  public MessageController(SuperManager superManager, MessageService messageService) {
    this.superManager = superManager;
    this.messageService = messageService;
  }

  @Operation(
      summary = "获取自己的消息",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "message", description = "查询实体"),
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  public R message(@Nullable PageDTO<Message> page, @Nullable Message message) {
    String name =
        ThreadLocalUtil.getByKey(Constants.NAME, ThreadLocalUtil.getByKey(Constants.NAME, ""));
    String realName = ThreadLocalUtil.getByKey(Constants.REAL_NAME, "");
    String tenant =
        ThreadLocalUtil.getByKey(Constants.TENANT, ThreadLocalUtil.getByKey(Constants.TENANT, ""));
    QueryWrapper<Message> queryWrapper = new QueryWrapper<>(message);
    if (!superManager.isReal()) {
      queryWrapper.or().eq("sender", name).or().eq("sender", realName);
      queryWrapper.or().like("recipient", "所有人");
      if (StrUtil.isNotBlank(name)) {
        queryWrapper.or().like("recipient", name);
      }
      if (StrUtil.isNotBlank(realName)) {
        queryWrapper.or().like("recipient", realName);
      }
      if (StrUtil.isNotBlank(tenant)) {
        queryWrapper.or().like("recipient", tenant);
      }
    }
    if (message != null && StrUtil.isNotEmpty(message.getDescription())) {
      queryWrapper.like("description", message.getDescription());
      message.setDescription(null);
    }
    queryWrapper.orderByAsc("status").orderByDesc("create_time");
    return success(messageService.page(page, queryWrapper));
  }

  /**
   * 新增数据.
   *
   * @param message 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "消息表 - 新增数据",
      parameters = {
        @Parameter(name = "message", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  public R insert(@RequestBody Message message) {
    if (message.getIsExpiry() != null && message.getIsExpiry()) {
      // 设置过期时间，10天后
      DateTime offset = DateUtil.offset(DateUtil.today(), DateField.DAY_OF_MONTH, 10);
      message.setExpiry(OffsetDateTime.of(DateUtil.toLocalDateTime(offset), ZoneOffset.ofHours(8)));
    }
    return success(this.messageService.save(message));
  }

  /**
   * 修改数据.
   *
   * @param message 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "消息表 - 修改数据",
      parameters = {@Parameter(name = "message", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  public R update(@RequestBody Message message) {
    if (message.getIsExpiry() != null && message.getIsExpiry()) {
      // 设置过期时间，10天后
      DateTime offset = DateUtil.offset(DateUtil.today(), DateField.DAY_OF_MONTH, 10);
      message.setExpiry(OffsetDateTime.of(DateUtil.toLocalDateTime(offset), ZoneOffset.ofHours(8)));
    }
    return success(this.messageService.saveOrUpdate(message));
  }

  /**
   * 标记为已读.
   *
   * @param id 主键
   * @return 修改结果
   */
  @Operation(
      summary = "消息表 - 通过主键已读单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "修改结果"))
  @PutMapping("read/{id}")
  public R read(@PathVariable("id") Serializable id) {
    Message message = this.messageService.getById(id);
    if (message.getIsExpiry()) {
      // 设置过期时间的消息不允许已读
      throw new RuntimeException("消息自动已读，不可手动设置");
    } else {
      message.setStatus(1);
    }
    return success(this.messageService.updateById(message));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "消息表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.messageService.removeByIds(idList));
  }
}
