package {{ cookiecutter.__mvn_package }}.module.schedule;

import com.baomidou.mybatisplus.core.plugins.IgnoreStrategy;
import com.baomidou.mybatisplus.core.plugins.InterceptorIgnoreHelper;
import {{ cookiecutter.__mvn_package }}.module.dao.CustomDao;
import jakarta.annotation.Resource;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import lombok.extern.slf4j.Slf4j;
import org.dromara.hutool.core.date.StopWatch;
import org.dromara.hutool.core.date.TimeUtil;
import org.dromara.hutool.core.lang.ConsoleTable;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * (ScheduledService) 定时任务.
 *
 * @author zweiandlen
 * @since 2024/7/3 下午2:27
 */
@Slf4j
@Component
public class ScheduledService {

  @Resource CustomDao customDao;

  /** 每天早上两点清理一个月前的日志. */
  @Scheduled(cron = "0 0 2 * * ?")
  public void clearLogger() {
    // 定时
    StopWatch watchClearLogger = StopWatch.of("日志清理");
    watchClearLogger.start();
    // 执行
    InterceptorIgnoreHelper.handle(IgnoreStrategy.builder().tenantLine(true).build());
    LocalDateTime offset = TimeUtil.offset(TimeUtil.of(TimeUtil.today()), -1, ChronoUnit.MONTHS);
    int size = customDao.clearLogger(offset);
    InterceptorIgnoreHelper.clearIgnoreStrategy();
    watchClearLogger.stop();
    // 统计
    ConsoleTable.of()
        .setSBCMode(true)
        .addHeader("定时任务", "日志时间", "删除行数", "耗时(毫秒)")
        .addBody(
            "日志清理",
            offset.toString(),
            String.valueOf(size),
            String.valueOf(watchClearLogger.getTotalTimeMillis()))
        .print();
  }

  /** 每天早上两点半执行一次过期消息. */
  @Scheduled(cron = "0 30 2 * * ?")
  public void expiryMessage() {
    // 定时
    StopWatch watchClearLogger = StopWatch.of("过期消息");
    watchClearLogger.start();
    // 执行
    InterceptorIgnoreHelper.handle(IgnoreStrategy.builder().tenantLine(true).build());
    int size = customDao.expiryMessage();
    InterceptorIgnoreHelper.clearIgnoreStrategy();
    watchClearLogger.stop();
    // 统计
    ConsoleTable.of()
        .setSBCMode(true)
        .addHeader("定时任务", "更新行数", "耗时(毫秒)")
        .addBody(
            "过期消息", String.valueOf(size), String.valueOf(watchClearLogger.getTotalTimeMillis()))
        .print();
  }
}
