/*
 * Copyright (c) 2011-2021, baomidou (jobob@qq.com).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package {{ cookiecutter.__mvn_package }}.rest.api;

import {{ cookiecutter.__mvn_package }}.rest.enums.ApiErrorCode;
import {{ cookiecutter.__mvn_package }}.rest.exceptions.ApiException;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serial;
import java.io.Serializable;
import java.util.Optional;
import lombok.Data;
import lombok.experimental.Accessors;
import lombok.extern.slf4j.Slf4j;

/**
 * REST API 返回结果.
 *
 * @author hubin
 * @since 2018-06-05
 */
@Schema(description = "通用响应体")
@Data
@Slf4j
@Accessors(chain = true)
public class R<T> implements Serializable {

  @Serial private static final long serialVersionUID = -1481239544950144592L;

  /** 错误码. */
  private long code;

  /** 结果集. */
  private T data;

  /** 描述. */
  private String msg;

  public R() {}

  /**
   * 按枚举初始化.
   *
   * @param errorCode 枚举
   */
  public R(ErrorCode errorCode) {
    errorCode = Optional.ofNullable(errorCode).orElse(ApiErrorCode.FAILED);
    this.code = errorCode.getCode();
    this.msg = errorCode.getMsg();
  }

  /**
   * 按内容构建响应结果.
   *
   * @param data 内容
   * @param <T> 类型
   * @return 响应结果
   */
  public static <T> R<T> ok(T data) {
    ApiErrorCode aec = ApiErrorCode.SUCCESS;
    if (data instanceof Boolean && Boolean.FALSE.equals(data)) {
      aec = ApiErrorCode.FAILED;
    }
    return restResult(data, aec);
  }

  public static <T> R<T> failed(String msg) {
    return restResult(null, ApiErrorCode.FAILED.getCode(), msg);
  }

  public static <T> R<T> failed(ErrorCode errorCode) {
    return restResult(null, errorCode);
  }

  public static <T> R<T> restResult(T data, ErrorCode errorCode) {
    return restResult(data, errorCode.getCode(), errorCode.getMsg());
  }

  private static <T> R<T> restResult(T data, long code, String msg) {
    R<T> apiResult = new R<>();
    apiResult.setCode(code);
    apiResult.setData(data);
    apiResult.setMsg(msg);
    return apiResult;
  }

  public boolean ok() {
    return ApiErrorCode.SUCCESS.getCode() == this.code;
  }

  /** 服务间调用非业务正常，异常直接释放. */
  public T serviceData() {
    if (!this.ok()) {
      throw new ApiException(this.msg);
    }
    return this.data;
  }
}
