package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.dev33.satoken.secure.BCrypt;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.mapper.AccountMapper;
import {{ cookiecutter.__mvn_package }}.mapper.entity.AccountExcel;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Account;
import {{ cookiecutter.__mvn_package }}.rest.service.AccountService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.nio.charset.StandardCharsets;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.dromara.hutool.core.io.IoUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.poi.excel.ExcelReader;
import org.dromara.hutool.poi.excel.ExcelUtil;
import org.dromara.hutool.poi.excel.ExcelWriter;
import org.springframework.http.HttpHeaders;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 凭据表(Account)表控制层.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:36
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tAccount")
@RequiredArgsConstructor
public class AccountController extends ApiController {
  /** 服务对象. */
  private final AccountService accountService;

  private final AccountMapper accountMapper;

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param account 查询实体
   * @param mention 提及
   * @return 分页数据
   */
  @Operation(
      summary = "凭据表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "account", description = "查询实体"),
        @Parameter(name = "mention", description = "提及")
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(
      @Nullable PageDTO<Account> page, @Nullable Account account, @Nullable String mention) {
    QueryWrapper<Account> queryWrapper = new QueryWrapper<>(account);
    if (account != null && StrUtil.isNotBlank(account.getName())) {
      queryWrapper.like("name", account.getName());
      account.setName(null);
    }
    if (account != null && StrUtil.isNotBlank(account.getRealName())) {
      queryWrapper.like("real_name", account.getRealName());
      account.setRealName(null);
    }
    if (StrUtil.isNotBlank(mention)) {
      queryWrapper.like("name", mention).or().like("real_name", mention);
    }
    return success(this.accountService.page(page, queryWrapper));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "凭据表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.accountService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param account 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "凭据表 - 新增数据",
      parameters = {
        @Parameter(name = "account", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody Account account) {
    if (StrUtil.isNotBlank(account.getPassword())) {
      account.setPassword(BCrypt.hashpw(account.getPassword()));
    }
    return success(this.accountService.save(account));
  }

  /**
   * 批量新增数据.
   *
   * @param accounts 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "凭据表 - 批量新增数据",
      parameters = {
        @Parameter(name = "accounts", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<Account> accounts) {
    accounts.forEach(
        item -> {
          if (StrUtil.isNotBlank(item.getPassword())) {
            item.setPassword(BCrypt.hashpw(item.getPassword()));
          }
        });
    return success(this.accountService.saveBatch(accounts));
  }

  /**
   * 修改数据.
   *
   * @param account 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "凭据表 - 修改数据",
      parameters = {@Parameter(name = "account", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody Account account) {
    if (StrUtil.isNotBlank(account.getPassword())) {
      account.setPassword(BCrypt.hashpw(account.getPassword()));
    }
    return success(this.accountService.saveOrUpdate(account));
  }

  /**
   * 批量修改数据.
   *
   * @param accounts 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "凭据表 - 批量修改数据",
      parameters = {@Parameter(name = "accounts", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<Account> accounts) {
    accounts.forEach(
        item -> {
          if (StrUtil.isNotBlank(item.getPassword())) {
            item.setPassword(BCrypt.hashpw(item.getPassword()));
          }
        });
    return success(this.accountService.saveOrUpdateBatch(accounts));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "凭据表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.accountService.removeByIds(idList));
  }

  /**
   * 导出符合条件的数据
   *
   * @param account 查询条件
   * @param response 响应内容
   */
  @GetMapping("export")
  @SaCheckPermission("db:rest:export")
  public void excelExport(@Nullable Account account, HttpServletResponse response)
      throws IOException {
    List<Account> list = this.accountService.list(new QueryWrapper<>(account));
    List<AccountExcel> excels = this.accountMapper.toExcel(list);
    ExcelWriter writer = ExcelUtil.getWriter();
    // 表头
    writer.addHeaderAlias("id", "唯一标识");
    writer.addHeaderAlias("name", "账户");
    writer.addHeaderAlias("realName", "名称");
    writer.addHeaderAlias("mobile", "手机号");
    writer.addHeaderAlias("email", "邮箱");
    writer.addHeaderAlias("isActive", "激活");
    writer.addHeaderAlias("status", "状态");
    writer.addHeaderAlias("description", "描述");
    writer.addHeaderAlias("createBy", "创建人");
    writer.addHeaderAlias("tenant", "租户");
    // 可选项
    if (!excels.isEmpty()) {
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 5, 5), "激活", "未激活");
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 6, 6), "可用", "禁用");
    } else {
      writer.addSelect(new CellRangeAddressList(1, 1, 5, 5), "激活", "未激活");
      writer.addSelect(new CellRangeAddressList(1, 1, 6, 6), "可用", "禁用");
    }
    // 默认的，未添加alias的属性也会写出，如果想只写出加了别名的字段，可以调用此方法排除之
    writer.setOnlyAlias(true);
    // 写入数据
    writer.write(excels, true);
    writer.autoSizeColumnAll();
    // 写到响应流
    response.setContentType(writer.getContentType());
    response.setHeader(
        HttpHeaders.CONTENT_DISPOSITION, writer.getDisposition("凭据", StandardCharsets.UTF_8));
    ServletOutputStream out = response.getOutputStream();
    writer.flush(out);
    // 关闭流
    IoUtil.closeQuietly(writer, out);
  }

  @PostMapping("import")
  @SaCheckPermission("db:rest:import")
  public R excelImport(@RequestParam("file") MultipartFile[] files) throws IOException {
    if (files == null || files.length < 1) throw new RuntimeException("文件上传失败");
    InputStream in = files[0].getInputStream();
    ExcelReader reader = ExcelUtil.getReader(in);
    // 表头
    reader.addHeaderAlias("唯一标识", "id");
    reader.addHeaderAlias("账户", "name");
    reader.addHeaderAlias("名称", "realName");
    reader.addHeaderAlias("手机号", "mobile");
    reader.addHeaderAlias("邮箱", "email");
    reader.addHeaderAlias("激活", "isActive");
    reader.addHeaderAlias("状态", "status");
    reader.addHeaderAlias("描述", "description");
    reader.addHeaderAlias("创建人", "createBy");
    reader.addHeaderAlias("租户", "tenant");

    List<AccountExcel> excels = reader.readAll(AccountExcel.class);
    List<Account> tenants = accountMapper.toEntity(excels);
    // 关闭流
    IoUtil.closeQuietly(reader, in);
    return success(accountService.saveOrUpdateBatch(tenants));
  }
}
