package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.mapper.AuthorityMapper;
import {{ cookiecutter.__mvn_package }}.mapper.entity.AuthorityExcel;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Authority;
import {{ cookiecutter.__mvn_package }}.rest.service.AuthorityService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.nio.charset.StandardCharsets;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.dromara.hutool.core.io.IoUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.poi.excel.ExcelReader;
import org.dromara.hutool.poi.excel.ExcelUtil;
import org.dromara.hutool.poi.excel.ExcelWriter;
import org.springframework.http.HttpHeaders;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 权限表(Authority)表控制层.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:34
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tAuthority")
@RequiredArgsConstructor
public class AuthorityController extends ApiController {
  /** 服务对象. */
  private final AuthorityService authorityService;

  private final AuthorityMapper authorityMapper;

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param authority 查询实体
   * @return 分页数据
   */
  @Operation(
      summary = "权限表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "authority", description = "查询实体"),
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(@Nullable PageDTO<Authority> page, @Nullable Authority authority) {
    QueryWrapper<Authority> queryWrapper = new QueryWrapper<>(authority);
    if (authority != null && StrUtil.isNotBlank(authority.getName())) {
      queryWrapper.like("name", authority.getName());
      authority.setName(null);
    }
    return success(this.authorityService.page(page, queryWrapper));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "权限表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.authorityService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param authority 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "权限表 - 新增数据",
      parameters = {
        @Parameter(name = "authority", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody Authority authority) {
    return success(this.authorityService.save(authority));
  }

  /**
   * 批量新增数据.
   *
   * @param authorities 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "权限表 - 批量新增数据",
      parameters = {
        @Parameter(name = "authorities", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<Authority> authorities) {
    return success(this.authorityService.saveBatch(authorities));
  }

  /**
   * 修改数据.
   *
   * @param authority 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "权限表 - 修改数据",
      parameters = {@Parameter(name = "authority", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody Authority authority) {
    return success(this.authorityService.saveOrUpdate(authority));
  }

  /**
   * 批量修改数据.
   *
   * @param authorities 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "权限表 - 批量修改数据",
      parameters = {@Parameter(name = "authorities", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<Authority> authorities) {
    return success(this.authorityService.saveOrUpdateBatch(authorities));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "权限表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.authorityService.removeByIds(idList));
  }

  /**
   * 导出符合条件的数据
   *
   * @param authority 查询条件
   * @param response 响应内容
   */
  @GetMapping("export")
  @SaCheckPermission("db:rest:export")
  public void excelExport(@Nullable Authority authority, HttpServletResponse response)
      throws IOException {
    List<Authority> list = this.authorityService.list(new QueryWrapper<>(authority));
    List<AuthorityExcel> excels = this.authorityMapper.toExcel(list);
    ExcelWriter writer = ExcelUtil.getWriter();
    // 表头
    writer.addHeaderAlias("id", "唯一标识");
    writer.addHeaderAlias("parentId", "父标识");
    writer.addHeaderAlias("name", "名称");
    writer.addHeaderAlias("value", "英文值");
    writer.addHeaderAlias("path", "路径");
    writer.addHeaderAlias("link", "外部链接");
    writer.addHeaderAlias("type", "类型");
    writer.addHeaderAlias("status", "状态");
    writer.addHeaderAlias("description", "描述");
    writer.addHeaderAlias("createBy", "创建人");
    writer.addHeaderAlias("tenant", "租户");
    // 可选项
    if (!excels.isEmpty()) {
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 6, 6), "接口", "菜单", "按钮");
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 7, 7), "可用", "禁用");
    } else {
      writer.addSelect(new CellRangeAddressList(1, 1, 6, 6), "接口", "菜单", "按钮");
      writer.addSelect(new CellRangeAddressList(1, 1, 7, 7), "可用", "禁用");
    }
    // 默认的，未添加alias的属性也会写出，如果想只写出加了别名的字段，可以调用此方法排除之
    writer.setOnlyAlias(true);
    // 写入数据
    writer.write(excels, true);
    writer.autoSizeColumnAll();
    // 写到响应流
    response.setContentType(writer.getContentType());
    response.setHeader(
        HttpHeaders.CONTENT_DISPOSITION, writer.getDisposition("权限", StandardCharsets.UTF_8));
    ServletOutputStream out = response.getOutputStream();
    writer.flush(out);
    // 关闭流
    IoUtil.closeQuietly(writer, out);
  }

  @PostMapping("import")
  @SaCheckPermission("db:rest:import")
  public R excelImport(@RequestParam("file") MultipartFile[] files) throws IOException {
    if (files == null || files.length < 1) throw new RuntimeException("文件上传失败");
    InputStream in = files[0].getInputStream();
    ExcelReader reader = ExcelUtil.getReader(in);
    // 表头
    reader.addHeaderAlias("唯一标识", "id");
    reader.addHeaderAlias("父标识", "parentId");
    reader.addHeaderAlias("名称", "name");
    reader.addHeaderAlias("英文值", "value");
    reader.addHeaderAlias("路径", "path");
    reader.addHeaderAlias("外部链接", "link");
    reader.addHeaderAlias("类型", "type");
    reader.addHeaderAlias("状态", "status");
    reader.addHeaderAlias("描述", "description");
    reader.addHeaderAlias("创建人", "createBy");
    reader.addHeaderAlias("租户", "tenant");
    List<AuthorityExcel> excels = reader.readAll(AuthorityExcel.class);
    List<Authority> tenants = authorityMapper.toEntity(excels);
    // 关闭流
    IoUtil.closeQuietly(reader, in);
    return success(authorityService.saveOrUpdateBatch(tenants));
  }
}
