package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.mapper.LoggerMapper;
import {{ cookiecutter.__mvn_package }}.mapper.entity.LoggerExcel;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Logger;
import {{ cookiecutter.__mvn_package }}.rest.service.LoggerService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.Serializable;
import java.nio.charset.StandardCharsets;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.dromara.hutool.core.io.IoUtil;
import org.dromara.hutool.poi.excel.ExcelUtil;
import org.dromara.hutool.poi.excel.ExcelWriter;
import org.springframework.http.HttpHeaders;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;

/**
 * 日志表(Logger)表控制层.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:33
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tLogger")
@RequiredArgsConstructor
public class LoggerController extends ApiController {
  /** 服务对象. */
  private final LoggerService loggerService;

  private final LoggerMapper loggerMapper;

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param logger 查询实体
   * @return 分页数据
   */
  @Operation(
      summary = "日志表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "logger", description = "查询实体"),
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(@Nullable PageDTO<Logger> page, @Nullable Logger logger) {
    return success(this.loggerService.page(page, new QueryWrapper<>(logger)));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "日志表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.loggerService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param logger 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "日志表 - 新增数据",
      parameters = {
        @Parameter(name = "logger", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody Logger logger) {
    return success(this.loggerService.save(logger));
  }

  /**
   * 批量新增数据.
   *
   * @param loggers 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "日志表 - 批量新增数据",
      parameters = {
        @Parameter(name = "loggers", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<Logger> loggers) {
    return success(this.loggerService.saveBatch(loggers));
  }

  /**
   * 修改数据.
   *
   * @param logger 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "日志表 - 修改数据",
      parameters = {@Parameter(name = "logger", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody Logger logger) {
    return success(this.loggerService.saveOrUpdate(logger));
  }

  /**
   * 批量修改数据.
   *
   * @param loggers 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "日志表 - 批量修改数据",
      parameters = {@Parameter(name = "loggers", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<Logger> loggers) {
    return success(this.loggerService.saveOrUpdateBatch(loggers));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "日志表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.loggerService.removeByIds(idList));
  }

  /**
   * 导出符合条件的数据
   *
   * @param logger 查询条件
   * @param response 响应内容
   */
  @GetMapping("export")
  @SaCheckPermission("db:rest:export")
  public void excelExport(@Nullable Logger logger, HttpServletResponse response)
      throws IOException {
    List<Logger> list = this.loggerService.list(new QueryWrapper<>(logger));
    List<LoggerExcel> excels = this.loggerMapper.toExcel(list);
    ExcelWriter writer = ExcelUtil.getWriter();
    // 表头
    writer.addHeaderAlias("id", "唯一标识");
    writer.addHeaderAlias("type", "类型");
    writer.addHeaderAlias("operate", "操作");
    writer.addHeaderAlias("tableName", "表名称");
    writer.addHeaderAlias("recordStatus", "打印日志");
    writer.addHeaderAlias("changed", "变动内容");
    writer.addHeaderAlias("description", "描述");
    writer.addHeaderAlias("createTime", "创建时间");
    writer.addHeaderAlias("createBy", "创建人");
    // 可选项
    if (!excels.isEmpty()) {
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 1, 1), "数据变更自动日志");
    } else {
      writer.addSelect(new CellRangeAddressList(1, 1, 1, 1), "数据变更自动日志");
    }
    // 默认的，未添加alias的属性也会写出，如果想只写出加了别名的字段，可以调用此方法排除之
    writer.setOnlyAlias(true);
    // 写入数据
    writer.write(excels, true);
    writer.autoSizeColumnAll();
    // 写到响应流
    response.setContentType(writer.getContentType());
    response.setHeader(
        HttpHeaders.CONTENT_DISPOSITION, writer.getDisposition("日志", StandardCharsets.UTF_8));
    ServletOutputStream out = response.getOutputStream();
    writer.flush(out);
    // 关闭流
    IoUtil.closeQuietly(writer, out);
  }
}
