package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.RoleAuthority;
import {{ cookiecutter.__mvn_package }}.rest.service.RoleAuthorityService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.io.Serializable;
import java.util.List;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;

/**
 * 角色权限关联表(RoleAuthority)表控制层.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:30
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tRoleAuthority")
public class RoleAuthorityController extends ApiController {
  /** 服务对象. */
  private final RoleAuthorityService roleAuthorityService;

  public RoleAuthorityController(RoleAuthorityService roleAuthorityService) {
    this.roleAuthorityService = roleAuthorityService;
  }

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param roleAuthority 查询实体
   * @return 分页数据
   */
  @Operation(
      summary = "角色权限关联表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "roleAuthority", description = "查询实体"),
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(@Nullable PageDTO<RoleAuthority> page, @Nullable RoleAuthority roleAuthority) {
    return success(this.roleAuthorityService.page(page, new QueryWrapper<>(roleAuthority)));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "角色权限关联表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.roleAuthorityService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param roleAuthority 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "角色权限关联表 - 新增数据",
      parameters = {
        @Parameter(name = "roleAuthority", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody RoleAuthority roleAuthority) {
    return success(this.roleAuthorityService.save(roleAuthority));
  }

  /**
   * 批量新增数据.
   *
   * @param roleAuthorities 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "角色权限关联表 - 批量新增数据",
      parameters = {
        @Parameter(name = "roleAuthorities", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<RoleAuthority> roleAuthorities) {
    return success(this.roleAuthorityService.saveBatch(roleAuthorities));
  }

  /**
   * 修改数据.
   *
   * @param roleAuthority 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "角色权限关联表 - 修改数据",
      parameters = {@Parameter(name = "roleAuthority", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody RoleAuthority roleAuthority) {
    return success(this.roleAuthorityService.saveOrUpdate(roleAuthority));
  }

  /**
   * 批量修改数据.
   *
   * @param roleAuthorities 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "角色权限关联表 - 批量修改数据",
      parameters = {@Parameter(name = "roleAuthorities", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<RoleAuthority> roleAuthorities) {
    return success(this.roleAuthorityService.saveOrUpdateBatch(roleAuthorities));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "角色权限关联表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.roleAuthorityService.removeByIds(idList));
  }
}
