package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import {{ cookiecutter.__mvn_package }}.mapper.TenantMapper;
import {{ cookiecutter.__mvn_package }}.mapper.entity.TenantExcel;
import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Tenant;
import {{ cookiecutter.__mvn_package }}.rest.service.TenantService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.nio.charset.StandardCharsets;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.dromara.hutool.core.io.IoUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.poi.excel.ExcelReader;
import org.dromara.hutool.poi.excel.ExcelUtil;
import org.dromara.hutool.poi.excel.ExcelWriter;
import org.springframework.http.HttpHeaders;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 租户表(Tenant)表控制层.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:29
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tTenant")
@RequiredArgsConstructor
public class TenantController extends ApiController {
  /** 服务对象. */
  private final TenantService tenantService;

  private final TenantMapper tenantMapper;

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param tenant 查询实体
   * @param mention 提及
   * @return 分页数据
   */
  @Operation(
      summary = "租户表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "tenant", description = "查询实体"),
        @Parameter(name = "mention", description = "提及")
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(
      @Nullable PageDTO<Tenant> page, @Nullable Tenant tenant, @Nullable String mention) {
    QueryWrapper<Tenant> queryWrapper = new QueryWrapper<>(tenant);
    if (tenant != null && StrUtil.isNotBlank(tenant.getName())) {
      queryWrapper.like("name", tenant.getName());
      tenant.setName(null);
    }
    if (StrUtil.isNotBlank(mention)) {
      queryWrapper.like("name", mention);
    }
    return success(this.tenantService.page(page, queryWrapper));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "租户表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.tenantService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param tenant 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "租户表 - 新增数据",
      parameters = {
        @Parameter(name = "tenant", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody Tenant tenant) {
    return success(this.tenantService.save(tenant));
  }

  /**
   * 批量新增数据.
   *
   * @param tenants 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "租户表 - 批量新增数据",
      parameters = {
        @Parameter(name = "tenants", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<Tenant> tenants) {
    return success(this.tenantService.saveBatch(tenants));
  }

  /**
   * 修改数据.
   *
   * @param tenant 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "租户表 - 修改数据",
      parameters = {@Parameter(name = "tenant", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody Tenant tenant) {
    return success(this.tenantService.saveOrUpdate(tenant));
  }

  /**
   * 批量修改数据.
   *
   * @param tenants 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "租户表 - 批量修改数据",
      parameters = {@Parameter(name = "tenants", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<Tenant> tenants) {
    return success(this.tenantService.saveOrUpdateBatch(tenants));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "租户表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.tenantService.removeByIds(idList));
  }

  /**
   * 导出符合条件的数据
   *
   * @param tenant 查询条件
   * @param response 响应内容
   */
  @GetMapping("export")
  @SaCheckPermission("db:rest:export")
  public void excelExport(@Nullable Tenant tenant, HttpServletResponse response)
      throws IOException {
    List<Tenant> list = this.tenantService.list(new QueryWrapper<>(tenant));
    List<TenantExcel> excels = this.tenantMapper.toExcel(list);
    ExcelWriter writer = ExcelUtil.getWriter();
    // 表头
    writer.addHeaderAlias("id", "唯一标识");
    writer.addHeaderAlias("name", "名称");
    writer.addHeaderAlias("shared", "共享租户");
    writer.addHeaderAlias("type", "类型");
    writer.addHeaderAlias("status", "状态");
    writer.addHeaderAlias("description", "描述");
    writer.addHeaderAlias("createBy", "创建人");
    // 可选项
    if (!excels.isEmpty()) {
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 3, 3), "企业", "个人");
      writer.addSelect(new CellRangeAddressList(1, excels.size(), 4, 4), "可用", "禁用");
    } else {
      writer.addSelect(new CellRangeAddressList(1, 1, 3, 3), "企业", "个人");
      writer.addSelect(new CellRangeAddressList(1, 1, 4, 4), "可用", "禁用");
    }
    // 默认的，未添加alias的属性也会写出，如果想只写出加了别名的字段，可以调用此方法排除之
    writer.setOnlyAlias(true);
    // 写入数据
    writer.write(excels, true);
    writer.autoSizeColumnAll();
    // 写到响应流
    response.setContentType(writer.getContentType());
    response.setHeader(
        HttpHeaders.CONTENT_DISPOSITION, writer.getDisposition("租户租户", StandardCharsets.UTF_8));
    ServletOutputStream out = response.getOutputStream();
    writer.flush(out);
    // 关闭流
    IoUtil.closeQuietly(writer, out);
  }

  @PostMapping("import")
  @SaCheckPermission("db:rest:import")
  public R excelImport(@RequestParam("file") MultipartFile[] files) throws IOException {
    if (files == null || files.length < 1) throw new RuntimeException("文件上传失败");
    InputStream in = files[0].getInputStream();
    ExcelReader reader = ExcelUtil.getReader(in);
    // 表头
    reader.addHeaderAlias("唯一标识", "id");
    reader.addHeaderAlias("名称", "name");
    reader.addHeaderAlias("共享租户", "shared");
    reader.addHeaderAlias("类型", "type");
    reader.addHeaderAlias("状态", "status");
    reader.addHeaderAlias("描述", "description");
    reader.addHeaderAlias("创建人", "createBy");
    List<TenantExcel> excels = reader.readAll(TenantExcel.class);
    List<Tenant> tenants = tenantMapper.toEntity(excels);
    // 关闭流
    IoUtil.closeQuietly(reader, in);
    return success(tenantService.saveOrUpdateBatch(tenants));
  }
}
