package {{ cookiecutter.__mvn_package }}.rest.entity;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.Version;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.time.OffsetDateTime;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.ibatis.type.JdbcType;

/**
 * 凭据表(Account)表实体类.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:36
 */
@Schema(description = "凭据表")
@EqualsAndHashCode(callSuper = true)
@Data
public class Account extends Model<Account> {
  // ID
  @Schema(description = "ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long id;

  // 账户
  @Schema(description = "账户")
  private String name;

  // 密码
  @Schema(description = "密码")
  @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
  private String password;

  // 名称
  @Schema(description = "名称")
  private String realName;

  // 手机号
  @Schema(description = "手机号")
  private String mobile;

  // 邮箱
  @Schema(description = "邮箱")
  private String email;

  // 状态(0:可用 1:禁用)
  @Schema(description = "状态(0:可用 1:禁用)")
  private Integer status;

  // 激活
  @Schema(description = "激活")
  private Integer isActive;

  // 关联角色ID
  @Schema(description = "关联角色ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private String roleIds;

  // 关联员工ID
  @Schema(description = "关联员工ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long staffId;

  // 关联会员ID
  @Schema(description = "关联会员ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long userId;

  // 描述
  @Schema(description = "描述")
  private String description;

  // 乐观锁
  @Schema(description = "乐观锁")
  @Version
  private Integer version;

  // 逻辑删除
  @Schema(description = "逻辑删除")
  @TableLogic
  private Long deleteTime;

  // 创建时间
  @Schema(description = "创建时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime createTime;

  // 修改时间
  @Schema(description = "修改时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime updateTime;

  // 创建人
  @Schema(description = "创建人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT)
  private String createBy;

  // 修改人
  @Schema(description = "修改人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateBy;

  // 租户
  @Schema(description = "租户")
  private String tenant;

  /**
   * 获取主键值.
   *
   * @return 主键值
   */
  @Override
  public Serializable pkVal() {
    return this.id;
  }
}
