package {{ cookiecutter.__mvn_package }}.rest.entity;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.time.OffsetDateTime;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.ibatis.type.JdbcType;

/**
 * 消息表(Message)表实体类.
 *
 * @author zweiandlen
 * @since 2025-04-21 15:27:06
 */
@Schema(description = "消息表")
@EqualsAndHashCode(callSuper = true)
@Data
public class Message extends Model<Message> {
  // ID
  @Schema(description = "ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long id;

  // 发送人
  @Schema(description = "发送人")
  private String sender;

  // 接收人
  @Schema(description = "接收人")
  private String recipient;

  // 定时失效
  @Schema(description = "定时失效")
  private Boolean isExpiry;

  // 过期时间
  @Schema(description = "过期时间")
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime expiry;

  // 状态(0:未读 1:已读)
  @Schema(description = "状态(0:未读 1:已读)")
  private Integer status;

  // 消息内容
  @Schema(description = "消息内容")
  private String description;

  // 逻辑删除
  @Schema(description = "逻辑删除")
  @TableLogic
  private Long deleteTime;

  // 创建时间
  @Schema(description = "创建时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime createTime;

  // 修改时间
  @Schema(description = "修改时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime updateTime;

  // 创建人
  @Schema(description = "创建人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT)
  private String createBy;

  // 修改人
  @Schema(description = "修改人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateBy;

  /**
   * 获取主键值.
   *
   * @return 主键值
   */
  @Override
  public Serializable pkVal() {
    return this.id;
  }
}
