package {{ cookiecutter.__mvn_package }}.rest.entity;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.Version;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.time.OffsetDateTime;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.ibatis.type.JdbcType;

/**
 * 租户表(Tenant)表实体类.
 *
 * @author zweiandlen
 * @since 2024-07-03 17:49:29
 */
@Schema(description = "租户表")
@EqualsAndHashCode(callSuper = true)
@Data
public class Tenant extends Model<Tenant> {
  // ID
  @Schema(description = "ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long id;

  // 名称
  @Schema(description = "名称")
  private String name;

  // 共享租户
  @Schema(description = "共享租户")
  private String shared;

  // 类型(0:企业 1:个人)
  @Schema(description = "类型(0:企业 1:个人)")
  private Integer type;

  // 状态(0:可用 1:禁用)
  @Schema(description = "状态(0:可用 1:禁用)")
  private Integer status;

  // 描述
  @Schema(description = "描述")
  private String description;

  // 乐观锁
  @Schema(description = "乐观锁")
  @Version
  private Integer version;

  // 逻辑删除
  @Schema(description = "逻辑删除")
  @TableLogic
  private Long deleteTime;

  // 创建时间
  @Schema(description = "创建时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime createTime;

  // 修改时间
  @Schema(description = "修改时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime updateTime;

  // 创建人
  @Schema(description = "创建人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT)
  private String createBy;

  // 修改人
  @Schema(description = "修改人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateBy;

  /**
   * 获取主键值.
   *
   * @return 主键值
   */
  @Override
  public Serializable pkVal() {
    return this.id;
  }
}
