package {{ cookiecutter.__mvn_package }}.service.impl;

import {{ cookiecutter.__mvn_package }}.config.CacheConfig;
import {{ cookiecutter.__mvn_package }}.service.CaptchaService;
import jakarta.annotation.Resource;
import java.util.Objects;
import lombok.extern.slf4j.Slf4j;
import org.dromara.hutool.core.lang.Validator;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.core.util.RandomUtil;
import org.dromara.hutool.extra.mail.MailUtil;
import org.dromara.hutool.swing.captcha.CaptchaUtil;
import org.dromara.hutool.swing.captcha.CircleCaptcha;
import org.dromara.hutool.swing.img.ImgUtil;
import org.springframework.cache.CacheManager;
import org.springframework.stereotype.Service;

/**
 * (CaptchaServiceImpl) 验证码服务实现.
 *
 * @author zweiandlen
 * @since 2024/7/3 下午3:29
 */
@Slf4j
@Service
public class CaptchaServiceImpl implements CaptchaService {

  @Resource CacheManager cacheManager;

  @Override
  public String getCodeById(String objectId) {
    CircleCaptcha circleCaptcha = CaptchaUtil.ofCircleCaptcha(125, 40);
    String code = circleCaptcha.getCode();
    log.info("图形验证码 {}", code);
    // 存到缓存
    Objects.requireNonNull(cacheManager.getCache(CacheConfig.CacheEnum.CAPTCHA.name()))
        .put(objectId, code);
    return ImgUtil.toBase64DataUri(circleCaptcha.getImage(), ImgUtil.IMAGE_TYPE_PNG);
  }

  @Override
  public String getCodeByEmail(String objectId, String email) {
    if (!Validator.isEmail(email)) {
      throw new RuntimeException("邮箱地址格式错误");
    }
    String code = RandomUtil.randomString(6);
    // 发送邮件
    String format = StrUtil.format("【江苏云展】{}（验证码，半小时内有效）", code);
    MailUtil.sendText(email, "no-reply", format);
    log.info("邮件验证码 {}", code);
    // 存到缓存
    Objects.requireNonNull(cacheManager.getCache(CacheConfig.CacheEnum.CAPTCHA.name()))
        .put(objectId, code);
    return objectId;
  }

  @Override
  public String getCodeBySms(String objectId, String mobile) {
    // todo
    throw new RuntimeException("短信验证码功能未实现");
  }

  @Override
  public Boolean checkCodeById(String objectId, String code) {
    String cacheCode =
        Objects.requireNonNull(cacheManager.getCache(CacheConfig.CacheEnum.CAPTCHA.name()))
            .get(objectId, String.class);
    Objects.requireNonNull(cacheManager.getCache(CacheConfig.CacheEnum.CAPTCHA.name()))
        .evictIfPresent(objectId);
    return StrUtil.compareIgnoreCase(code, cacheCode, true) == 0;
  }
}
