package {{ cookiecutter.__mvn_package }}.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import {{ cookiecutter.__mvn_package }}.enums.AuthorityType;
import {{ cookiecutter.__mvn_package }}.enums.Status;
import {{ cookiecutter.__mvn_package }}.rest.entity.Account;
import {{ cookiecutter.__mvn_package }}.rest.entity.Authority;
import {{ cookiecutter.__mvn_package }}.rest.entity.Role;
import {{ cookiecutter.__mvn_package }}.rest.entity.RoleAuthority;
import {{ cookiecutter.__mvn_package }}.rest.service.AccountService;
import {{ cookiecutter.__mvn_package }}.rest.service.AuthorityService;
import {{ cookiecutter.__mvn_package }}.rest.service.RoleAuthorityService;
import {{ cookiecutter.__mvn_package }}.rest.service.RoleService;
import {{ cookiecutter.__mvn_package }}.service.OwnService;
import {{ cookiecutter.__mvn_package }}.web.SuperManager;
import jakarta.annotation.Resource;
import java.util.List;
import org.dromara.hutool.core.collection.CollUtil;
import org.dromara.hutool.core.collection.ListUtil;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.core.text.split.SplitUtil;
import org.springframework.stereotype.Service;

/**
 * (OwnServiceImpl) 用户拥有资源的实现.
 *
 * @author zweiandlen
 * @since 2024/4/1 15:17
 */
@Service
public class OwnServiceImpl implements OwnService {

  @Resource SuperManager superManager;
  @Resource AccountService accountService;
  @Resource RoleService roleService;
  @Resource AuthorityService authorityService;
  @Resource RoleAuthorityService roleAuthorityService;

  @Override
  public List<String> getOwnAuths(String id) {
    return CollUtil.unionAll(this.getOwnRole(id), this.getOwnAuthority(id));
  }

  private List<String> roleIds(String id) {
    Account find = accountService.getById(id);
    if (find == null) {
      throw new RuntimeException("用户不存在");
    }
    String roleStr = find.getRoleIds();
    if (StrUtil.isBlank(roleStr)) {
      return ListUtil.empty();
    }
    List<String> roleIds = SplitUtil.split(roleStr, StrUtil.COMMA, true, true);
    if (CollUtil.isEmpty(roleIds)) {
      return ListUtil.empty();
    }
    return roleIds;
  }

  private List<String> authorityIds(String id) {
    List<String> roleIds = this.roleIds(id);
    if (CollUtil.isEmpty(roleIds)) return ListUtil.empty();
    List<RoleAuthority> roleAuthorities =
        roleAuthorityService.list(
            Wrappers.lambdaQuery(RoleAuthority.class).in(RoleAuthority::getRoleId, roleIds));
    List<String> authorityIds =
        roleAuthorities.stream().map(item -> String.valueOf(item.getAuthorityId())).toList();
    if (CollUtil.isEmpty(authorityIds)) {
      return ListUtil.empty();
    }
    return authorityIds;
  }

  @Override
  public List<String> getOwnRole(String id) {
    // 判断超级管理员
    if (superManager.isReal()) {
      return List.of("*");
    }
    List<String> roleIds = this.roleIds(id);
    if (CollUtil.isEmpty(roleIds)) return ListUtil.empty();
    List<Role> roles = roleService.list(Wrappers.lambdaQuery(Role.class).in(Role::getId, roleIds));
    return roles.stream().map(role -> "ROLE_" + role.getValue()).distinct().toList();
  }

  @Override
  public List<String> getOwnAuthority(String id) {
    // 判断超级管理员
    if (superManager.isReal()) {
      return List.of("*");
    }
    List<String> authorityIds = this.authorityIds(id);
    if (CollUtil.isEmpty(authorityIds)) return ListUtil.empty();
    List<Authority> authorities =
        authorityService.list(
            Wrappers.lambdaQuery(Authority.class).in(Authority::getId, authorityIds));
    return authorities.stream().map(Authority::getValue).distinct().toList();
  }

  @Override
  public List<Authority> getOwnMenus(String id) {
    // 判断超级管理员
    if (superManager.isReal()) {
      return authorityService.list(
          Wrappers.lambdaQuery(Authority.class)
              .eq(Authority::getType, AuthorityType.MENU.getField())
              .eq(Authority::getStatus, Status.ENABLE.getField()));
    }
    List<String> authorityIds = this.authorityIds(id);
    if (CollUtil.isEmpty(authorityIds)) return ListUtil.empty();
    return authorityService.list(
        Wrappers.lambdaQuery(Authority.class)
            .in(Authority::getId, authorityIds)
            .eq(Authority::getType, AuthorityType.MENU.getField())
            .eq(Authority::getStatus, Status.ENABLE.getField()));
  }

  @Override
  public List<Authority> getOwnButtons(String id) {
    // 判断超级管理员
    if (superManager.isReal()) {
      return authorityService.list(
          Wrappers.lambdaQuery(Authority.class)
              .eq(Authority::getType, AuthorityType.BUTTON.getField())
              .eq(Authority::getStatus, Status.ENABLE.getField()));
    }
    return authorityService.list(
        Wrappers.lambdaQuery(Authority.class)
            .in(Authority::getId, this.authorityIds(id))
            .eq(Authority::getType, AuthorityType.BUTTON.getField())
            .eq(Authority::getStatus, Status.ENABLE.getField()));
  }
}
