package {{ cookiecutter.__mvn_package }}.utils;

import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.crypto.SecureUtil;
import org.dromara.hutool.crypto.asymmetric.KeyType;

/**
 * (CryptoUtil) 加解密工具.
 *
 * @author zweiandlen
 * @since 2024/7/10 上午10:20
 */
public class CryptoUtil {

  public static final String PUB =
      """
      MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDORIceR8iDNIdH366iHZ9LCrkq
      VF84SRgO0JsZO79vc/1hcsECcs7kQCtFD9kj5Bz4P4iMJQ+hZeaPBKmrfHl91DDr
      hjuACgA3Pk0Pr5TBdN3eemA0Ri50NyjhoGpJvE8dZe1sbn4lfQwtOsx+kmP+Ixb3
      oa6wdPQb3gfnQJqxDQIDAQAB
      """;
  private static final String PRIV =
      """
      MIICeAIBADANBgkqhkiG9w0BAQEFAASCAmIwggJeAgEAAoGBAM5Ehx5HyIM0h0ff
      rqIdn0sKuSpUXzhJGA7Qmxk7v29z/WFywQJyzuRAK0UP2SPkHPg/iIwlD6Fl5o8E
      qat8eX3UMOuGO4AKADc+TQ+vlMF03d56YDRGLnQ3KOGgakm8Tx1l7WxufiV9DC06
      zH6SY/4jFvehrrB09BveB+dAmrENAgMBAAECgYEAuGP2ThFppDDfBldlq7LDZbgO
      U1LdVFmzUfsVy3bn6WBNEEIfXGr5nH3osHI8cKNJanqRPIcc8/E+LHfEnXJGv6K7
      DLjZpVA86Ld20ekNeoLZWOAkZe3x8f4RhQcPhG+D/830EBb0apR4aOsAkZr6YZcA
      uuf/4mA7/j3e2ziePlkCQQD8Yvt5Vh6DLp2Lvu4+4IKzmmaIziK882334EJzDdEj
      eo/xbb2y1oQt06AFOBlodHovkCcVulz1lh8k+fijaWNDAkEA0TiEBkLkATYmhVBd
      MzeUwcDp2pAuNUpNC0u4LYHlGXiBLTRHn1iV1LWPofU01CsUd4PD2Gb5qnV+ah3K
      BCTNbwJATPWh2Q35n+bHA6Xk4Cd1s26RdYXl8dgI4Fzx5kOAUmE9I1FjVvUyuQae
      9Ph2RvO9jmNWh7mcPwbX2F6hArNQIQJBAMqdnN4jcYPq2StKRLgRH7L0DIVqFBXv
      uuUxk1Ae96vPE+qfMq2SsKeqnUsPmPXQMqX7qXKtZyQ5XQ+PgdC5g2kCQQD2aWmD
      eBsUwWcvm1V+/AdIw+iH+F35Z2hpTj6HVjuWS59NTkdXME9EdSnBj6NnY+Vpkqh/
      786hIVViDmxAmSXh
      """;

  /**
   * 字符串加密.
   *
   * @param text 明文
   * @return 密文
   */
  public static String encrypt(String text) {
    return SecureUtil.rsa(StrUtil.cleanBlank(PRIV), StrUtil.cleanBlank(PUB))
        .encryptHex(text, KeyType.PublicKey);
  }

  /**
   * 字符串解密.
   *
   * @param text 密文
   * @return 明文
   */
  public static String decrypt(String text) {
    return SecureUtil.rsa(StrUtil.cleanBlank(PRIV), StrUtil.cleanBlank(PUB))
        .decryptStr(text, KeyType.PrivateKey);
  }
}
