package {{ cookiecutter.__mvn_package }}.utils;

import com.alibaba.ttl.TransmittableThreadLocal;
import java.util.Map;
import java.util.Optional;
import org.dromara.hutool.core.convert.Convert;
import org.dromara.hutool.core.reflect.TypeReference;

/**
 * (ThreadLocalUtil) 线程上下文工具.
 *
 * @author zweiandlen
 * @since 2024/8/13 09:59
 */
public class ThreadLocalUtil {

  private static final ThreadLocal<Map<String, Object>> INFO_HOLDER =
      new TransmittableThreadLocal<>();

  /**
   * 按键值取值.
   *
   * @param key 键
   * @return 值
   */
  public static <T> T getByKey(String key, T defaultValue) {
    if (Optional.ofNullable(INFO_HOLDER.get()).isPresent() && INFO_HOLDER.get().get(key) != null) {
      return Convert.convert(new TypeReference<T>() {}, INFO_HOLDER.get().get(key));
    }
    return defaultValue;
  }

  /**
   * 按键值对存值.
   *
   * @param key 键
   * @param obj 值
   */
  public static void setByKey(String key, Object obj) {
    Optional.ofNullable(INFO_HOLDER.get()).ifPresent(val -> val.put(key, obj));
  }

  /**
   * 按键值对存值.
   *
   * @param map 键值对
   */
  public static void setMap(Map<String, Object> map) {
    INFO_HOLDER.set(map);
  }

  /** 清空线程的值. */
  public static void clear() {
    Optional.ofNullable(INFO_HOLDER.get())
        .ifPresent(
            (map) -> {
              map.clear();
              INFO_HOLDER.remove();
            });
  }
}
