package {{ cookiecutter.__mvn_package }}.web;

import com.alibaba.ttl.TtlRunnable;
import com.baomidou.mybatisplus.extension.plugins.inner.DataChangeRecorderInnerInterceptor;
import {{ cookiecutter.__mvn_package }}.common.Constants;
import {{ cookiecutter.__mvn_package }}.enums.LoggerType;
import {{ cookiecutter.__mvn_package }}.rest.entity.Logger;
import {{ cookiecutter.__mvn_package }}.rest.service.LoggerService;
import {{ cookiecutter.__mvn_package }}.utils.ThreadLocalUtil;
import java.util.List;
import java.util.Map;
import lombok.extern.slf4j.Slf4j;
import org.dromara.hutool.core.convert.Convert;
import org.dromara.hutool.core.reflect.TypeReference;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.core.thread.ThreadUtil;
import org.dromara.hutool.extra.spring.SpringUtil;
import org.dromara.hutool.json.JSONUtil;

/**
 * (DataChangeInnerInterceptor) 数据变更拦截器.
 *
 * @author zweiandlen
 * @since 2024/4/28 上午9:11
 */
@Slf4j
public class DataChangeInnerInterceptor extends DataChangeRecorderInnerInterceptor {

  @Override
  protected void dealOperationResult(OperationResult operationResult) {
    // 打印日志
    super.dealOperationResult(operationResult);
    // 保存日志，异步
    ThreadUtil.execAsync(TtlRunnable.get(() -> save(operationResult)));
  }

  /**
   * 保存数据变动到数据库 logger 表.
   *
   * @param operationResult 操作结果
   */
  public void save(OperationResult operationResult) {
    try {
      if (StrUtil.equalsIgnoreCase(operationResult.getTableName(), "logger")) {
        return;
      }

      String changedData = operationResult.getChangedData();
      changedData = StrUtil.replace(changedData, "}{", "},{");
      List<Map<String, String>> json =
          Convert.convert(new TypeReference<>() {}, JSONUtil.parseArray(changedData));

      Logger logger = new Logger();
      logger.setType(LoggerType.DB_AUTO_CHANGE.getField());
      logger.setOperation(operationResult.getOperation());
      logger.setTableName(operationResult.getTableName());
      logger.setRecordStatus(operationResult.isRecordStatus());
      logger.setDescription(this.description(json, logger.getOperation(), changedData));
      logger.setTenant(ThreadLocalUtil.getByKey(Constants.TENANT, StrUtil.EMPTY));
      logger.setChanged(JSONUtil.toJsonStr(json));
      LoggerService loggerService = SpringUtil.getBean(LoggerService.class);
      if (!json.isEmpty()) {
        loggerService.save(logger);
      }
    } catch (Exception e) {
      // 日志存储数据库失败，无需处理
      log.error(e.getMessage(), e);
    }
  }

  private String description(List<Map<String, String>> json, String operation, String changedData) {
    StringBuilder builder = StrUtil.builder();
    // 判断是否批量操作
    if (json.size() > 1) {
      builder.append("[");
      builder.append(LoggerType.DB_AUTO_CHANGE.getDescription());
      builder.append("] ");
      builder.append("批量");
    } else if (json.size() == 1) {
      builder.append("[");
      builder.append(LoggerType.DB_AUTO_CHANGE.getDescription());
      builder.append("] ");
      builder.append("单行");
    } else {
      return builder.toString();
    }
    // 判断操作
    if (StrUtil.equalsIgnoreCase("insert", operation)) {
      builder.append("新增");
    } else if (StrUtil.equalsIgnoreCase("delete", operation)) {
      builder.append("实际删除");
    } else if (StrUtil.equalsIgnoreCase("update", operation)
        && StrUtil.containsIgnoreCase(changedData, "delete_time")) {
      builder.append("逻辑删除");
    } else {
      builder.append("更新");
    }
    return builder.toString();
  }
}
