package {{ cookiecutter.__mvn_package }}.web;

import {{ cookiecutter.__mvn_package }}.config.CacheConfig;
import java.util.Objects;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.cache.Cache;
import org.dromara.hutool.core.text.StrUtil;
import org.dromara.hutool.extra.spring.SpringUtil;
import org.springframework.cache.Cache.ValueWrapper;
import org.springframework.cache.CacheManager;

/**
 * (MybatisCache) 数据库二级缓存.
 *
 * @author zweiandlen
 * @since 2024/6/13 下午4:53
 */
@Slf4j
public class MybatisCache implements Cache {

  private static final CacheManager CACHE_MANAGER = SpringUtil.getBean(CacheManager.class);

  private final ReadWriteLock readWriteLock = new ReentrantReadWriteLock(true);

  private String id;

  /**
   * 构造函数.
   *
   * @param id 缓存ID
   */
  public MybatisCache(String id) {
    if (StrUtil.isBlank(id)) {
      throw new IllegalArgumentException("数据二级缓存，ID必填");
    }
    this.id = id;
  }

  @Override
  public String getId() {
    return this.id;
  }

  @Override
  public void putObject(Object key, Object value) {
    if (value != null) {
      Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name()))
          .put(key, value);
    }
  }

  @Override
  public Object getObject(Object key) {
    if (key != null) {
      ValueWrapper valueWrapper =
          Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name()))
              .get(key);
      if (Objects.nonNull(valueWrapper)) {
        return valueWrapper.get();
      } else {
        return null;
      }
    } else {
      return null;
    }
  }

  @Override
  public Object removeObject(Object key) {
    Object value =
        Objects.requireNonNull(
                Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name()))
                    .get(key))
            .get();
    Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name())).evict(key);
    return value;
  }

  @Override
  public void clear() {
    Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name())).clear();
  }

  @Override
  public int getSize() {
    com.github.benmanes.caffeine.cache.Cache nativeCache =
        (com.github.benmanes.caffeine.cache.Cache)
            Objects.requireNonNull(CACHE_MANAGER.getCache(CacheConfig.CacheEnum.DATA.name()))
                .getNativeCache();
    return (int) nativeCache.estimatedSize();
  }
}
