package {{ cookiecutter.__mvn_package }}.web;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.handler.TenantLineHandler;
import com.baomidou.mybatisplus.extension.plugins.inner.TenantLineInnerInterceptor;
import {{ cookiecutter.__mvn_package }}.rest.dao.TenantDao;
import {{ cookiecutter.__mvn_package }}.rest.entity.Tenant;
import jakarta.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;
import net.sf.jsqlparser.expression.Expression;
import net.sf.jsqlparser.expression.StringValue;
import net.sf.jsqlparser.expression.operators.relational.InExpression;
import net.sf.jsqlparser.expression.operators.relational.ParenthesedExpressionList;
import net.sf.jsqlparser.schema.Table;
import org.dromara.hutool.core.text.StrUtil;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * (OrgLineInnerInterceptor) tenant 为空字符串时，为公共数据.
 *
 * @author zweiandlen
 * @since 2024/4/10 下午12:54
 */
@Component
public class OrgLineInnerInterceptor extends TenantLineInnerInterceptor {

  @Resource @Lazy private TenantDao tenantDao;

  public OrgLineInnerInterceptor(TenantLineHandler tenantLineHandler) {
    super(tenantLineHandler);
  }

  @Override
  public Expression buildTableExpression(Table table, Expression where, String whereSegment) {
    if (getTenantLineHandler().ignoreTable(table.getName())) return null;
    // 租户数据
    StringValue tenantPri = (StringValue) getTenantLineHandler().getTenantId();
    // 公共数据
    StringValue tenantPub = new StringValue(StrUtil.EMPTY);
    if (StrUtil.isNotBlank(tenantPri.getValue())) {
      List<String> list =
          tenantDao
              .selectList(
                  Wrappers.lambdaQuery(Tenant.class)
                      .eq(Tenant::getName, tenantPri.getValue())
                      .or()
                      .like(Tenant::getShared, tenantPri.getValue()))
              .stream()
              .map(Tenant::getName)
              .collect(Collectors.toList());
      list.add(StrUtil.EMPTY);
      StringValue[] array = list.stream().map(StringValue::new).toArray(StringValue[]::new);
      return new InExpression(getAliasColumn(table), new ParenthesedExpressionList<>(array));
    } else {
      return new InExpression(
          getAliasColumn(table), new ParenthesedExpressionList<>(tenantPri, tenantPub));
    }
  }
}
