-- account definition

CREATE TABLE `account`
(
    `id`          bigint                                                        NOT NULL COMMENT 'ID',
    `name`        varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '账户',
    `password`    varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '密码',
    `real_name`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '名称',
    `mobile`      varchar(20)                                                            DEFAULT NULL COMMENT '手机号',
    `email`       varchar(50)                                                            DEFAULT NULL COMMENT '邮箱',
    `status`      int                                                           NOT NULL DEFAULT '0' COMMENT '状态(0:可用 1:禁用)',
    `is_active`   int                                                           NOT NULL DEFAULT '0' COMMENT '激活',
    `role_ids`    text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '关联角色ID',
    `staff_id`    bigint                                                                 DEFAULT NULL COMMENT '关联员工ID',
    `user_id`     bigint                                                                 DEFAULT NULL COMMENT '关联会员ID',
    `description` text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述',
    `version`     int                                                           NOT NULL DEFAULT '0' COMMENT '乐观锁',
    `delete_time` bigint                                                        NOT NULL DEFAULT '0' COMMENT '逻辑删除',
    `create_time` datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    `tenant`      varchar(100)                                                  NOT NULL COMMENT '租户',
    PRIMARY KEY (`id`),
    UNIQUE KEY `account_unique_name` (`name`, `delete_time`),
    UNIQUE KEY `account_unique_mobile` (`mobile`, `delete_time`),
    UNIQUE KEY `account_unique_email` (`email`, `delete_time`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='凭据表';


-- authority definition

CREATE TABLE `authority`
(
    `id`          bigint                                                        NOT NULL COMMENT 'ID',
    `parent_id`   bigint                                                        NOT NULL DEFAULT '0' COMMENT '父节点',
    `name`        varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '名称',
    `value`       varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '英文值',
    `path`        varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '路径',
    `link`        varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '外部链接',
    `type`        int                                                           NOT NULL DEFAULT '0' COMMENT '类型(0:接口 1:菜单 2:按钮)',
    `status`      int                                                           NOT NULL DEFAULT '0' COMMENT '状态(0:可用 1:禁用)',
    `description` text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述',
    `version`     int                                                           NOT NULL DEFAULT '0' COMMENT '乐观锁',
    `delete_time` bigint                                                        NOT NULL DEFAULT '0' COMMENT '逻辑删除',
    `create_time` datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    `tenant`      varchar(100)                                                  NOT NULL COMMENT '租户',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='权限表';

INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (1, 0, '标准接口', 'db:rest', '', '', 0, 0, '标准的数据操作接口', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (2, 1, '查询', 'db:rest:get', '', '', 0, 0, '标准接口 / 查询数据', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (3, 1, '新增', 'db:rest:post', '', '', 0, 0, '标准接口 / 新增数据', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (4, 1, '修改', 'db:rest:put', '', '', 0, 0, '标准接口 / 修改数据', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (5, 1, '删除', 'db:rest:del', '', '', 0, 0, '标准接口 / 删除数据', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (6, 0, '系统管理', 'system', '/system', '', 1, 0, '系统管理菜单', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (7, 6, '多租户', 'system:tenant', '/system/tenant', '', 1, 0, '系统管理 / 多租户维护', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (8, 6, '维护权限', 'system:authority', '/system/authority', '', 1, 0, '系统管理 / 维护权限（包含接口、菜单、按钮）',
        0, 0, '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (9, 6, '维护角色', 'system:role', '/system/role', '', 1, 0, '系统管理 / 维护角色 / 配置角色拥有的权限', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (10, 6, '登录凭据', 'system:account', '/system/account', '', 1, 0,
        '系统管理 / 登录凭据（维护凭据，分配角色，对应员工与用户）', 0, 0, '1970-01-01 00:00:00', NULL, '超级管理员', NULL,
        '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (11, 6, '日志', 'system:logger', '/system/logger', '', 1, 0, '系统管理 / 日志（系统日志，业务日志，其他分类）', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (12, 8, '新增权限', 'system:authority:post', '', '', 2, 0, '系统管理 / 维护权限 / 新增权限', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (13, 8, '修改权限', 'system:authority:put', '', '', 2, 0, '系统管理 / 维护权限 / 修改权限', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (14, 8, '删除权限', 'system:authority:del', '', '', 2, 0, '系统管理 / 维护权限 / 删除权限', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (15, 9, '新增角色', 'system:role:post', '', '', 2, 0, '系统管理 / 维护角色 / 新增角色', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (16, 9, '修改角色', 'system:role:put', '', '', 2, 0, '系统管理 / 维护角色 / 修改角色', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (17, 9, '删除角色', 'system:role:del', '', '', 2, 0, '系统管理 / 维护角色 / 删除角色', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (18, 10, '新增凭据', 'system:account:post', '', '', 2, 0, '系统管理 / 登录凭据 / 新增凭据', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (19, 10, '修改凭据', 'system:account:put', '', '', 2, 0, '系统管理 / 登录凭据 / 修改凭据', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (20, 10, '删除凭据', 'system:account:del', '', '', 2, 0, '系统管理 / 登录凭据 / 删除凭据', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (21, 7, '新增租户', 'system:tenant:post', NULL, NULL, 2, 0, '系统管理 / 多租户 / 新增租户', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (22, 7, '修改租户', 'system:tenant:put', NULL, NULL, 2, 0, '系统管理 / 多租户 / 修改租户', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (23, 7, '删除租户', 'system:tenant:del', NULL, NULL, 2, 0, '系统管理 / 多租户 / 删除租户', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (24, 11, '删除日志', 'system:logger:del', NULL, NULL, 2, 0, '系统管理 / 日志 / 删除日志', 0, 0,
        '1970-01-01 00:00:00', NULL, '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (25, 0, '新增消息', 'message:post', NULL, NULL, 2, 0, '新增消息', 0, 0, '1970-01-01 00:00:00', NULL,
        '超级管理员', NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (26, 0, '修改消息', 'message:put', NULL, NULL, 2, 0, '修改消息', 0, 0, '1970-01-01 00:00:00', NULL, '超级管理员',
        NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (27, 0, '删除消息', 'message:del', NULL, NULL, 2, 0, '删除消息', 0, 0, '1970-01-01 00:00:00', NULL, '超级管理员',
        NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (28, 0, '导入表格', 'import:excel', '', '', 0, 0, '表格导入', 0, 0, '1970-01-01 00:00:00', NULL, '超级管理员',
        NULL, '');
INSERT INTO authority (id, parent_id, name, value, `path`, link, `type`, status, description, version, delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (29, 0, '导出表格', 'export:excel', '', '', 0, 0, '表格导出', 0, 0, '1970-01-01 00:00:00', NULL, '超级管理员',
        NULL, '');

-- logger definition

CREATE TABLE `logger`
(
    `id`            bigint                                                        NOT NULL COMMENT 'ID',
    `type`          int                                                           NOT NULL DEFAULT '0' COMMENT '类型(0:数据变更自动日志)',
    `operation`     varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NOT NULL COMMENT '操作',
    `table_name`    varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci           DEFAULT NULL COMMENT '表名称',
    `record_status` bit(1)                                                                 DEFAULT NULL COMMENT '打印日志',
    `changed`       longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '变动内容',
    `description`   text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述',
    `delete_time`   bigint                                                        NOT NULL DEFAULT '0' COMMENT '逻辑删除',
    `create_time`   datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time`   datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`     varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`     varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    `tenant`        varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '租户',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='日志表';


-- message definition

CREATE TABLE `message`
(
    `id`          bigint                                  NOT NULL COMMENT 'ID',
    `sender`      varchar(100) COLLATE utf8mb4_general_ci NOT NULL COMMENT '发送人',
    `recipient`   text COLLATE utf8mb4_general_ci COMMENT '接收人',
    `is_expiry`   bit(1)                                  NOT NULL              DEFAULT b'0' COMMENT '定时失效',
    `expiry`      datetime                                                      DEFAULT NULL COMMENT '过期时间',
    `status`      int                                     NOT NULL              DEFAULT '0' COMMENT '状态(0:未读 1:已读)',
    `description` text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '消息内容',
    `delete_time` bigint                                  NOT NULL              DEFAULT '0' COMMENT '逻辑删除',
    `create_time` datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime                                                      DEFAULT NULL COMMENT '修改时间',
    `create_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '创建人',
    `update_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '修改人',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='消息表';


-- `role` definition

CREATE TABLE `role`
(
    `id`          bigint                                                        NOT NULL COMMENT 'ID',
    `name`        varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '名称',
    `value`       varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '英文值',
    `status`      int                                                           NOT NULL DEFAULT '0' COMMENT '状态(0:可用 1:禁用)',
    `description` text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述',
    `version`     int                                                           NOT NULL DEFAULT '0' COMMENT '乐观锁',
    `delete_time` bigint                                                        NOT NULL DEFAULT '0' COMMENT '逻辑删除',
    `create_time` datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    `tenant`      varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '租户',
    PRIMARY KEY (`id`),
    UNIQUE KEY `role_unique_name` (`name`, `delete_time`),
    UNIQUE KEY `role_unique_value` (`value`, `delete_time`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='角色表';


-- role_authority definition

CREATE TABLE `role_authority`
(
    `id`           bigint                                                        NOT NULL COMMENT 'ID',
    `role_id`      bigint                                                        NOT NULL COMMENT '角色ID',
    `authority_id` bigint                                                        NOT NULL COMMENT '权限ID',
    `half`         bit(1)                                                        NOT NULL DEFAULT b'0' COMMENT '半选',
    `version`      int                                                           NOT NULL DEFAULT '0' COMMENT '乐观锁',
    `create_time`  datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time`  datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`    varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`    varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    `tenant`       varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '租户',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='角色权限关联表';

-- tenant definition

CREATE TABLE `tenant`
(
    `id`          bigint                                                        NOT NULL COMMENT 'ID',
    `name`        varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '名称',
    `shared`      text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '共享租户',
    `type`        int                                                           NOT NULL DEFAULT '0' COMMENT '类型(0:企业 1:个人)',
    `status`      int                                                           NOT NULL DEFAULT '0' COMMENT '状态(0:可用 1:禁用)',
    `description` text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述',
    `version`     int                                                           NOT NULL DEFAULT '0' COMMENT '乐观锁',
    `delete_time` bigint                                                        NOT NULL DEFAULT '0' COMMENT '逻辑删除',
    `create_time` datetime                                                               DEFAULT NULL COMMENT '创建时间',
    `update_time` datetime                                                               DEFAULT NULL COMMENT '修改时间',
    `create_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '创建人',
    `update_by`   varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci          DEFAULT NULL COMMENT '修改人',
    PRIMARY KEY (`id`),
    UNIQUE KEY `tenant_unique_name` (`name`, `delete_time`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT ='租户表';