-- public.account definition

-- Drop table

-- DROP TABLE account;

CREATE TABLE account
(
    id          int8           NOT NULL,
    "name"      varchar(100)   NOT NULL,
    "password"  varchar(100)   NOT NULL,
    real_name   varchar(100)   NULL,
    mobile      varchar(20)    NULL,
    email       varchar(50)    NULL,
    status      int4 DEFAULT 0 NOT NULL,
    is_active   int4 DEFAULT 0 NOT NULL,
    role_ids    text           NULL,
    staff_id    int8           NULL,
    user_id     int8           NULL,
    description text           NULL,
    "version"   int4 DEFAULT 0 NOT NULL,
    delete_time int8 DEFAULT 0 NOT NULL,
    create_time timestamptz    NULL,
    update_time timestamptz    NULL,
    create_by   varchar(100)   NULL,
    update_by   varchar(100)   NULL,
    tenant      varchar(100)   NOT NULL,
    CONSTRAINT t_account_pk PRIMARY KEY (id),
    CONSTRAINT t_account_unique_email UNIQUE (email),
    CONSTRAINT t_account_unique_mobile UNIQUE (mobile),
    CONSTRAINT t_account_unique_name UNIQUE (name)
);


-- public.authority definition

-- Drop table

-- DROP TABLE authority;

CREATE TABLE authority
(
    id          int8           NOT NULL,
    parent_id   int8 DEFAULT 0 NOT NULL,
    "name"      varchar(100)   NOT NULL,
    value       varchar(100)   NOT NULL,
    "path"      varchar(200)   NULL,
    link        varchar(100)   NULL,
    "type"      int4 DEFAULT 0 NOT NULL,
    status      int4 DEFAULT 0 NOT NULL,
    description text           NULL,
    "version"   int4 DEFAULT 0 NOT NULL,
    delete_time int8 DEFAULT 0 NOT NULL,
    create_time timestamptz    NULL,
    update_time timestamptz    NULL,
    create_by   varchar(100)   NULL,
    update_by   varchar(100)   NULL,
    tenant      varchar(100)   NOT NULL,
    CONSTRAINT t_authority_pk PRIMARY KEY (id)
);

INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (1, 0, '标准接口', 'db:rest', '', '', 0, 0, '标准的数据操作接口', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (2, 1, '查询', 'db:rest:get', '', '', 0, 0, '标准接口 / 查询数据', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (3, 1, '新增', 'db:rest:post', '', '', 0, 0, '标准接口 / 新增数据', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (4, 1, '修改', 'db:rest:put', '', '', 0, 0, '标准接口 / 修改数据', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (5, 1, '删除', 'db:rest:del', '', '', 0, 0, '标准接口 / 删除数据', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (6, 0, '系统管理', 'system', '/system', '', 1, 0, '系统管理菜单', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (7, 6, '多租户', 'system:tenant', '/system/tenant', '', 1, 0, '系统管理 / 多租户维护', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (8, 6, '维护权限', 'system:authority', '/system/authority', '', 1, 0, '系统管理 / 维护权限（包含接口、菜单、按钮）',
        0, 0, '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (9, 6, '维护角色', 'system:role', '/system/role', '', 1, 0, '系统管理 / 维护角色 / 配置角色拥有的权限', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (10, 6, '登录凭据', 'system:account', '/system/account', '', 1, 0,
        '系统管理 / 登录凭据（维护凭据，分配角色，对应员工与用户）', 0, 0, '1970-01-01 00:00:00.000', NULL, '超级管理员',
        '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (11, 6, '日志', 'system:logger', '/system/logger', '', 1, 0, '系统管理 / 日志（系统日志，业务日志，其他分类）', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (12, 8, '新增权限', 'system:authority:post', '', '', 2, 0, '系统管理 / 维护权限 / 新增权限', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (13, 8, '修改权限', 'system:authority:put', '', '', 2, 0, '系统管理 / 维护权限 / 修改权限', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (14, 8, '删除权限', 'system:authority:del', '', '', 2, 0, '系统管理 / 维护权限 / 删除权限', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (15, 9, '新增角色', 'system:role:post', '', '', 2, 0, '系统管理 / 维护角色 / 新增角色', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (16, 9, '修改角色', 'system:role:put', '', '', 2, 0, '系统管理 / 维护角色 / 修改角色', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (17, 9, '删除角色', 'system:role:del', '', '', 2, 0, '系统管理 / 维护角色 / 删除角色', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (18, 10, '新增凭据', 'system:account:post', '', '', 2, 0, '系统管理 / 登录凭据 / 新增凭据', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (19, 10, '修改凭据', 'system:account:put', '', '', 2, 0, '系统管理 / 登录凭据 / 修改凭据', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (20, 10, '删除凭据', 'system:account:del', '', '', 2, 0, '系统管理 / 登录凭据 / 删除凭据', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (21, 7, '新增租户', 'system:tenant:post', '', '', 2, 0, '系统管理 / 多租户 / 新增租户', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (22, 7, '修改租户', 'system:tenant:put', '', '', 2, 0, '系统管理 / 多租户 / 修改租户', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (23, 7, '删除租户', 'system:tenant:del', '', '', 2, 0, '系统管理 / 多租户 / 删除租户', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (24, 11, '删除日志', 'system:logger:del', '', '', 2, 0, '系统管理 / 日志 / 删除日志', 0, 0,
        '1970-01-01 00:00:00.000', NULL, '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (25, 0, '新增消息', 'message:post', '', '', 2, 0, '新增消息', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (26, 0, '修改消息', 'message:put', '', '', 2, 0, '修改消息', 0, 0, '1970-01-01 00:00:00.000', NULL, '超级管理员',
        '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (27, 0, '删除消息', 'message:del', '', '', 2, 0, '删除消息', 0, 0, '1970-01-01 00:00:00.000', NULL, '超级管理员',
        '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (28, 0, '导入表格', 'import:excel', '', '', 0, 0, '表格导入', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');
INSERT INTO authority (id, parent_id, "name", value, "path", link, "type", status, description, "version", delete_time,
                       create_time, update_time, create_by, update_by, tenant)
VALUES (29, 0, '导出表格', 'export:excel', '', '', 0, 0, '表格导出', 0, 0, '1970-01-01 00:00:00.000', NULL,
        '超级管理员', '', '');


-- public.logger definition

-- Drop table

-- DROP TABLE logger;

CREATE TABLE logger
(
    id            int8           NOT NULL,
    "type"        int4 DEFAULT 0 NOT NULL,
    operation     varchar(50)    NOT NULL,
    table_name    varchar(50)    NULL,
    record_status bool           NULL,
    changed       text           NULL,
    description   text           NULL,
    delete_time   int8 DEFAULT 0 NOT NULL,
    create_time   timestamptz    NULL,
    update_time   timestamptz    NULL,
    create_by     varchar(100)   NULL,
    update_by     varchar(100)   NULL,
    tenant        varchar(100)   NOT NULL,
    CONSTRAINT t_logger_pk PRIMARY KEY (id)
);


-- public.message definition

-- Drop table

-- DROP TABLE message;

CREATE TABLE message
(
    id          int8               NOT NULL,
    sender      varchar(100)       NOT NULL,
    recipient   text               NULL,
    is_expiry   bool DEFAULT false NOT NULL,
    expiry      timestamptz        NULL,
    status      int4 DEFAULT 0     NOT NULL,
    description text               NULL,
    delete_time int8 DEFAULT 0     NOT NULL,
    create_time timestamptz        NULL,
    update_time timestamptz        NULL,
    create_by   varchar(100)       NULL,
    update_by   varchar(100)       NULL,
    CONSTRAINT message_pk PRIMARY KEY (id)
);


-- public."role" definition

-- Drop table

-- DROP TABLE "role";

CREATE TABLE "role"
(
    id          int8           NOT NULL,
    "name"      varchar(100)   NOT NULL,
    value       varchar(100)   NOT NULL,
    status      int4 DEFAULT 0 NOT NULL,
    description text           NULL,
    "version"   int4 DEFAULT 0 NOT NULL,
    delete_time int8 DEFAULT 0 NOT NULL,
    create_time timestamptz    NULL,
    update_time timestamptz    NULL,
    create_by   varchar(100)   NULL,
    update_by   varchar(100)   NULL,
    tenant      varchar(100)   NOT NULL,
    CONSTRAINT t_role_pk PRIMARY KEY (id),
    CONSTRAINT t_role_unique_name UNIQUE (name),
    CONSTRAINT t_role_unique_value UNIQUE (value)
);


-- public.role_authority definition

-- Drop table

-- DROP TABLE role_authority;

CREATE TABLE role_authority
(
    id           int8               NOT NULL,
    role_id      int8 DEFAULT 0     NOT NULL,
    authority_id int8 DEFAULT 0     NOT NULL,
    half         bool DEFAULT false NOT NULL,
    "version"    int4 DEFAULT 0     NOT NULL,
    create_time  timestamptz        NULL,
    update_time  timestamptz        NULL,
    create_by    varchar(100)       NULL,
    update_by    varchar(100)       NULL,
    tenant       varchar(100)       NOT NULL,
    CONSTRAINT t_role_authority_pk PRIMARY KEY (id)
);


-- public.tenant definition

-- Drop table

-- DROP TABLE tenant;

CREATE TABLE tenant
(
    id          int8           NOT NULL,
    "name"      varchar(100)   NOT NULL,
    shared      text           NULL,
    "type"      int4 DEFAULT 0 NOT NULL,
    status      int4 DEFAULT 0 NOT NULL,
    description text           NULL,
    "version"   int4 DEFAULT 0 NOT NULL,
    delete_time int8 DEFAULT 0 NOT NULL,
    create_time timestamptz    NULL,
    update_time timestamptz    NULL,
    create_by   varchar(100)   NULL,
    update_by   varchar(100)   NULL,
    CONSTRAINT t_organization_pk PRIMARY KEY (id),
    CONSTRAINT t_organization_unique_name UNIQUE (name)
);